/*----------------------------------------------

[Themeasy Core JavaScript]

Theme   : Gomax
Version : 1.0.0
Author  : Themeasy
Support : https://themeasy.co

----------------------------------------------*/

/*----------------------------------------------

[Content Index]

1. Preloader
2. Animated Underline
3. Contact Form
4. Custom Select
5. Tooltip
6. Modal
7. Favorite Comment
8. Smooth Scroll
9. Ornament
10. Animation
11. Helper
12. Widgets

----------------------------------------------*/

/*----------------------------------------------
1. Preloader
----------------------------------------------*/

// #region Preloader

jQuery(function ($) {
  'use strict';

  var image = $('img'),
    element = $('#preloader'),
    emblem  = $('#preloader .emblem'),
    delay   = element.data('delay'),
    limit   = element.data('limit');

  function init() {
    element.addClass('loaded'),
      sessionStorage.setItem('gomax_preloader_' + location.href, location.href);
  }
  null === sessionStorage.getItem('gomax_preloader_' + location.href) &&
    emblem.css('opacity', 1),
    imagesLoaded(image, function () {
      delay || (delay = 0),
        limit || (limit = 1e4),
        setTimeout(function () {
          init();
        }, delay);
    }),
    setTimeout(function () {
      init();
    }, limit);
});

// #endregion Preloader

/*----------------------------------------------
2. Animated Underline
----------------------------------------------*/

// #region Animated Underline

jQuery(function ($) {
	'use strict';

	$('mark').each(function () {
		var $this = $(this);

		$this.one('inview', function (event, isInView) {

			if ( isInView ) {
				if ( ! $this.hasClass('when-hover') ) {
					setTimeout(function () {
						$this.addClass('active');
					}, 600)

				} else {
					let parent = $this.parents().eq(1);
					parent.hover(function () {
						$this.addClass('active');
					})
				}
			}
		})
	})
})

// #endregion Animated Underline

/*----------------------------------------------
3. Contact Form
----------------------------------------------*/

// #region Contact Form

jQuery(function($) {
  'use strict';

  $('.tms-form').each(function() {

    // Init
    var init = $(this).find('.form-area.delay-init');
    setTimeout(function() {
      init.removeClass('delay-init');
    }, 1000) 

    // Basic
    if ( $(this).hasClass('basic-form') ) {

      $(this).find('.form-floating').each(function() {
        $(this).prepend($(this).find('.form-label'));
      })
      
      $(this).find('.form-control').attr('placeholder', '');
      $(this).find('.form-floating').removeClass('form-floating');
    }

    // Compact
    if ( $(this).hasClass('compact-form') ) {
      $(this).find('.form-label:not(.form-check-label)').remove();
      $(this).find('.form-floating').removeClass('form-floating');
    }
  
    // Form
    var form = $(this).find('.wpcf7-form.init');
    form.addClass('form-fields needs-validation'); 

    // Acceptance
    var acceptance = $(this).find('.wpcf7-acceptance');  
    acceptance.find('input[type="checkbox"]').addClass('form-check-input');
    acceptance.find('.wpcf7-list-item-label').addClass('form-label form-check-label');

    // Button
    var area = $(this).find('.form-area');
    var button = $(this).find('.form-button');

    var overlay_button = $(this).find('.overlay-button');

    if ( overlay_button.length > 0 ) {
      button.remove();

      overlay_button.html('<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24" fill="none" stroke="currentColor" stroke-width="2" stroke-linecap="round" stroke-linejoin="round" class="feather feather-arrow-up-right overlay-icon"><line x1="7" y1="17" x2="17" y2="7"></line><polyline points="7 7 17 7 17 17"></polyline></svg>');

    } else {
      $(area).append(button);
    }
  })
})

// #endregion Contact Form

// #region Form Validation

jQuery(function ($) {
	'use strict';

	var required_form = $('.needs-validation, .needs-validation form');

	Array.prototype.slice.call(required_form).forEach(function (form) {

		// Submit
		form.addEventListener('submit', function (event) {

			// Check
			if ( ! form.checkValidity() ) {
				event.preventDefault();
				event.stopPropagation();
			}

			// Validation
			form.classList.add('was-validated');

		}, false);
	})
})

// #endregion Form Validation

// #region Price Switcher

jQuery(function ($) {
	'use strict';

	function countUp(countFrom, countTo) {

		var selector = { countNum: countFrom.text() };
		
		$(selector).animate({ countNum: countTo },
			{
				duration: 1000,
				easing: 'linear',
				step: function () {
					countFrom.text(Math.floor(this.countNum));
				},
				complete: function () {
					countFrom.text(this.countNum);
				}
			}
		)
	}

	$('.js-switch-price').each(function () {

		var $this = $(this);
		var button = $this.find('.js-switch-price-button');
		var price = $this.find('.price');

		price.each(function () {
			$(this).css('display', 'inline-block');
			$(this).css('width', ($(this).width() + 15));
		})

		button.click(function () {

			price.each(function () {
				var $this = $(this), monthly_value = $this.data('monthly'), annual_value = $this.data('annual');

				if ($this.text() == monthly_value) {
					countUp($this, annual_value);

				} else {
					countUp($this, monthly_value);
				}
			})
		})
	})
})

// #endregion Price Switcher

/*----------------------------------------------
4. Custom Select
----------------------------------------------*/

// #region Custom Select

jQuery(function ($) {
  'use strict';

  $('select.tms-custom-select').each(function() {		
		var select = $(this);
		
		var custom_select = document.createElement('div');
		custom_select.setAttribute('class', select.attr('class'));
		
		var select_trigger = document.createElement('span');
		select_trigger.setAttribute('class', 'tms-custom-select-trigger');
		select_trigger.appendChild(document.createTextNode(select.attr('placeholder')));
		
		var custom_options = document.createElement('div');
		custom_options.setAttribute('class', 'custom-options');

    select.find('option').each(function() {
			var option = $(this);

      if (option.hasClass('selected')) {
        var option_class = 'custom-option selected';
      } else {
        var option_class = 'custom-option';
      }
		
			var custom_option = document.createElement('span');
			custom_option.setAttribute('class', option_class);
			custom_option.setAttribute('data-value', option.attr('value'));
			custom_option.appendChild(document.createTextNode(option.text()));
			
			custom_options.append(custom_option);
    })
		
		custom_select.append(custom_options);
		custom_select.prepend(select_trigger);

    select.after(custom_select);

		if ( select.hasClass('edit-mode') ) {
    	select.remove();
		} else {
			select.hide();
		}
  })

  $('.tms-custom-select-trigger').on('click', function(e) {
    $('html').one('click', function() {
      $('.tms-custom-select').removeClass('opened');
    })

    $(this).parents('.tms-custom-select').toggleClass('opened');
    e.stopPropagation();
  })
  
  $('.custom-option').on('click', function() {
    $(this).parents('.tms-custom-select-wrapper').find('select').val($(this).data('value'));
    $(this).parents('.custom-options').find('.custom-option').removeClass('selected');
    $(this).addClass('selected');
    $(this).parents('.tms-custom-select').removeClass('opened');
    $(this).parents('.tms-custom-select').find('.tms-custom-select-trigger').text($(this).text());

    $('.tms-custom-select').trigger('change');
  })
})

// #endregion Custom Select

/*----------------------------------------------
5. Tooltip
----------------------------------------------*/

// #region Tooltip

jQuery(function ($) {
  'use strict';

  $(document).on('mouseenter', '.tooltip-trigger', function() {
    var tooltip_trigger = $(this);
    var tooltip_text    = tooltip_trigger.data('tooltip');
		var tooltip_el      = tooltip_trigger.children('.tms-tooltip');

    if (typeof tooltip_text === 'undefined' || tooltip_text === '') {
      return;
    }

    if (tooltip_el.length === 0) {
      tooltip_trigger.prepend(
        '<div class="tms-tooltip">'+tooltip_text+'</div>'
      );			
      setTimeout(function() {
        tooltip_trigger.addClass('tooltip-active');
      }, 100 )
    }
  })

  $(document).on('mouseleave', '.tooltip-trigger', function() {
    var tooltip_trigger = $(this);
    tooltip_trigger.removeClass('tooltip-active');
    tooltip_trigger.find('.tms-tooltip').remove();
  })
})

// #endregion Tooltip

/*----------------------------------------------
6. Modal
----------------------------------------------*/

// #region Modal

jQuery(function($) {
  'use strict';

  var body    = $('body');
  var header  = $('#header');
  var overlay = $('.tms-modal .close-button, .tms-modal .dimiss-modal, .tms-modal .tms-modal-overlay');

  $(document).on('click', '.tms-modal-trigger', function() {
		var target = $(this).data('target');
		var modal  = $('.tms-modal[data-target="'+target+'"]');;

    body.css('overflow', 'hidden');
    body.css('padding-right', '17px');
    header.css('z-index', '0');

    modal.addClass('show');
  })

  overlay.on('click', function() {
    setTimeout(function() {
      body.css('overflow', '');
      body.css('padding-right', '');
			header.css('z-index', '');
    }, 600)

    $('.tms-modal').removeClass('show');
  })
})

// #endregion Modal

/*----------------------------------------------
7. Favorite Comment
----------------------------------------------*/

// #region Favorite Comment

jQuery(function ($) {
	'use strict';

	$('.favorite-comment').each(function() {

		var ID = $(this).attr('id');
		var hasFavorite = localStorage.hasOwnProperty( ID )

		// Load
		if ( hasFavorite ) {
			var favorite = localStorage.getItem( ID );
			$('#'+favorite).addClass('active');
		}
		
		// Set
		$(this).click(function() {

			if ( $(this).hasClass('active') ) {				
				$(this).removeClass('active');
				localStorage.removeItem( ID );

			} else {
				$(this).addClass('active');
				localStorage.setItem( ID, ID );
			}
		})
	})
})

// #endregion Favorite Comment

/*----------------------------------------------
8. Smooth Scroll
----------------------------------------------*/

// #region Smooth Scroll

/* 
Checks if the main element exists and if the page is not in an iframe.
*/
if ( document.getElementById('smooth-scroll-content') && window.location === window.parent.location ) {
	gsap.registerPlugin(ScrollTrigger);

	/* 
	Setup: wrap your content <div> in another <div> that will serve as the viewport.
	Call this function FIRST (before you create your ScrollTriggers); it sets the 
	default "scroller" for you (otherwise it'd be the window/body, but it should be 
	the content <div>) 
	*/
	smoothScroll('#smooth-scroll-content', '#smooth-scroll-viewport');

	// Pin each item for 300px when they hit the top.
	gsap.utils.toArray('.smooth-scroll-item').forEach(item => {
		ScrollTrigger.create({
			trigger: item,
			pin: true,
			start: 'top top',
			end: '+=300'
		})
	})

	/* 
	This is the helper function that sets it all up. Pass in the content <div> and then the wrapping viewport <div> (can be the elements or selector text). 
	It also sets the default 'scroller' to the content so you don't have to do that on all your ScrollTriggers.
	*/
	function smoothScroll(content, viewport, smoothness) {
		content = gsap.utils.toArray(content)[0];
		smoothness = smoothness || 1;

		gsap.set(viewport || content.parentNode, {overflow: 'hidden', position: 'fixed', height: '100%', width: '100%', top: 0, left: 0, right: 0, bottom: 0})
		gsap.set(content, {overflow: 'visible', width: '100%'})

		let getProp = gsap.getProperty(content),
			setProp = gsap.quickSetter(content, 'y', 'px'),
			setScroll = ScrollTrigger.getScrollFunc(window),
			removeScroll = () => content.style.overflow = 'visible',
			killScrub = trigger => {
				let scrub = trigger.getTween ? trigger.getTween() : gsap.getTweensOf(trigger.animation)[0]; // getTween() was added in 3.6.2
				scrub && scrub.pause();
				trigger.animation.progress(trigger.progress);
			},
			height, isProxyScrolling;

		function refreshHeight() {
			height = content.clientHeight;
			content.style.overflow = 'visible'
			document.body.style.height = height + 'px';
			return height - document.documentElement.clientHeight;
		}

		ScrollTrigger.addEventListener('refresh', () => {
			removeScroll();
			requestAnimationFrame(removeScroll);
		})
		ScrollTrigger.defaults({scroller: content})
		ScrollTrigger.prototype.update = p => p; // works around an issue in ScrollTrigger 3.6.1 and earlier (fixed in 3.6.2, so this line could be deleted if you're using 3.6.2 or later).

		ScrollTrigger.scrollerProxy(content, {
			scrollTop(value) {
				if (arguments.length) {
					isProxyScrolling = true; // otherwise, if snapping was applied (or anything that attempted to SET the scroll proxy's scroll position), we'd set the scroll here which would then (on the next tick) update the content tween/ScrollTrigger which would try to smoothly animate to that new value, thus the scrub tween would impede the progress. So we use this flag to respond accordingly in the ScrollTrigger's onUpdate and effectively force the scrub to its end immediately.
					setProp(-value);
					setScroll(value);
					return;
				}
				return -getProp('y');
			},
			scrollHeight: () => document.body.scrollHeight,
			getBoundingClientRect() {
				return {top: 0, left: 0, width: window.innerWidth, height: window.innerHeight};
			}
		})

		return ScrollTrigger.create({
			animation: gsap.fromTo(content, {y:0}, {
				y: () => document.documentElement.clientHeight - height,
				ease: 'none',
				onUpdate: ScrollTrigger.update
			}),
			scroller: window,
			invalidateOnRefresh: true,
			start: 0,
			end: refreshHeight,
			refreshPriority: -999,
			scrub: smoothness,
			onUpdate: self => {
				if (isProxyScrolling) {
					killScrub(self);
					isProxyScrolling = false;
				}
			},
			onRefresh: killScrub // when the screen resizes, we just want the animation to immediately go to the appropriate spot rather than animating there, so basically kill the scrub.
		})
	}
}

// #endregion Smooth Scroll

/*----------------------------------------------
9. Ornament
----------------------------------------------*/

// #region Ornament

jQuery(function($) {
	'use strict';

	$('.tms-bg-move').on( 'mousemove', function(e) {
		requestAnimationFrame(() => {
			const x = e.pageX - e.target.offsetLeft;
			const y = e.pageY - e.target.offsetTop;
			e.target.style.setProperty('--x', `${ x }px`);
			e.target.style.setProperty('--y', `${ y }px`);		
		})
	})
})

// #endregion Ornament

/*----------------------------------------------
10. Animation
----------------------------------------------*/

// #region Animation

jQuery(function($) {
	'use strict';

	var element = $('.tms-animation');

	$(window).scroll(function() {

		// Runs the animation for each item separately.
		element.each(function() {
			var item = $(this);

			const animation     = item.data('animation');
			const elementMiddle = item.offset().top + ( 0.5 * item.height() );
			const windowBottom  = $(window).scrollTop() + $(window).height();
					
			if (item.hasClass('tms-animation') && elementMiddle < windowBottom) {

				// Applies animation to the element's children.
				if ( item.hasClass('tms-animation-parent') ) {
					item.find('.tms-animation-children').addClass(animation);
					item.find('span span').addClass(animation);
				} else {
					item.addClass(animation);
				}
				
				// Remove animation classes to avoid conflict with hover classes.
				setTimeout(function() {
					item.removeClass(animation);
					item.removeClass('tms-animation');
					item.removeClass('tms-animation-parent');
				}, 2000)
			}
		})
	})

	// On Load: Trigger Scroll Once
	$(window).scroll();
})

// #endregion Animation

/*----------------------------------------------
11. Helper
----------------------------------------------*/

// #region Helper

// Force reload JS
jQuery(function ($) {
	'use strict';

	$.fn.force_reload_js = function(script_to_find) {
		$.each($('script:empty[src*="' + script_to_find + '"]'), function(index, el) {
			var script_id  = $(el).attr('id');
			var script_src = $(el).attr('src');

			$(el).remove();
			$('<script/>').attr('id', script_id).attr('src', script_src).appendTo('body');

			// console.log(script_to_find, 'js_reloaded');
		})
	}
})

// Adds style from attribute
jQuery(function ($) {
	'use strict';

	// Text Color
	$('[data-text-color]').each(function () {
		let attr = $(this).data('text-color');
		$(this).css('color',  attr);
	})

	// Background Color
	$('[data-bg-color]').each(function () {
		let attr = $(this).data('bg-color');
		$(this).css('background-color',  attr);
	})

	// Background Image
	$('[data-bg-image]').each(function () {
		let attr = $(this).data('bg-image');
		$(this).css('background-image', 'url(' + attr + ')');
	})
})

// Focus trigger to element
jQuery(function ($) {
	'use strict';

	var item = $('.focus-trigger');

	item.each(function() {

		$(this).hover(function() {
			$(this).find('.focus-trigger-field').trigger('focus');
		})
	})
})

// Give the correct size to the scrolling text button.
jQuery(function ($) {
	'use strict';

	var button = $('.button.tms-vertical-scroll-text');

	button.each(function() {

		// Get visible text values
		var width_values = [];
		button.find('[class*="text"]').each(function() {
			let width = $(this).outerWidth();
			width_values.push(width);
		})

		// Find the tallest item
		var max_button_width = Math.max.apply(Math, width_values);

		// Add width to button
		button.css( 'width', max_button_width + 35 + 'px' );
	})
})

// #endregion Helper

/*----------------------------------------------
12. Widgets
----------------------------------------------*/

// #region Popup

// Popup Bar
void ( function (root, factory) {

	if ( typeof define === 'function' && define.amd ) {
		define(factory);
	
	} else if ( typeof exports === 'object' ) {
		module.exports = factory();
	
	} else {
		root.PopupBar = factory();
	}

} (this, function () {

		function PopupBar() {
			ready(run);
		}
	
		const popupbar = document.getElementById('popup-bar');
		const navbar = document.querySelector('.navbar.smart-scroll, .navbar.fixed-scroll');

		function run() {
			if ( window.localStorage.PopupBarDismissed ) {
				return;
			} 

			show();
		}

		function dismiss() {
			var notice = document.getElementById('popup-bar');

			if ( notice ) {
				notice.classList.remove('popup-bar-animation');
			}

			if ( notice ) {
				notice.classList.add('popup-bar-exit-animation');
			}

			window.localStorage.PopupBarDismissed = true;
				
			if (navbar) {
				navbar.style.top = '0';
			}
		}

		function undismiss() {
			delete window.localStorage.PopupBarDismissed;
		}

		function show() {
			var $dismiss = document.getElementById('popup-bar-dismiss');
			if ($dismiss !== null) {
				$dismiss.onclick = dismiss;
			}

			var $div = document.getElementById('popup-bar');
			if ($div !== null) {
				$div.classList.remove('d-none');
				$div.classList.add('popup-bar-animation');
				
				if (navbar) {
					navbar.style.top = '50px';
				}
			}
		}

		function ready(fn) {
			if ( document.readyState === 'complete' ) {
				return fn();

			} else if ( document.addEventListener ) {
				document.addEventListener('DOMContentLoaded', fn);

			} else {
				document.attachEvent('onreadystatechange', function () {
					if (document.readyState === 'interactive') fn()
				})
			}
		}

		PopupBar.run = run;
		PopupBar.dismiss = dismiss;
		PopupBar.undismiss = undismiss;

		return PopupBar
	})
)
setTimeout(function() {
	PopupBar();
}, 6000)

// Popup Box
void (function (root, factory) {
	if ( typeof define === 'function' && define.amd ) {
		define(factory);

	} else if ( typeof exports === 'object' ) {
		module.exports = factory();
	
	}	else {
		root.PopupBox = factory()
	}

} (this, function () {	
		function PopupBox() {
			ready(run);
		}

		function run() {
			if ( window.localStorage.PopupBoxDismissed ) {
				return;
			}
			show();
		}

		function add_backdrop() {
			const element = document.getElementById('popup-box');

			if ( element !== null ) {
				var backdrop = document.createElement('div');
				backdrop.setAttribute('id', 'popup-box-backdrop');
				backdrop.setAttribute('class', 'modal-backdrop fade show');
				document.body.append(backdrop);
				document.body.style.overflow = 'hidden';
				document.body.style.paddingRight = '17px';
			}
		}

		function remove_backdrop() {
			var backdrop = document.getElementById('popup-box-backdrop');
			backdrop.remove();

			setTimeout(function() {
				document.body.style.overflow = '';
				document.body.style.paddingRight = '';
			}, 600)
		}

		function dismiss() {
			var notice = document.getElementById('popup-box');

			if ( notice ) {
				notice.classList.remove('popup-box-animation');
				notice.classList.remove('active');
			}

			if ( notice ) {
				notice.classList.add('popup-box-exit-animation');
				notice.classList.remove('active');
			}
			
			window.localStorage.PopupBoxDismissed = true;

			remove_backdrop();
		}

		function undismiss() {
			delete window.localStorage.PopupBoxDismissed;
		}

		function show() {
			var $dismiss = document.getElementById('popup-box-dismiss');
			if ($dismiss !== null) {
				$dismiss.onclick = dismiss;
			}

			var $div = document.getElementById('popup-box');
			if ($div !== null) {
				$div.classList.remove('d-none');
				$div.classList.add('popup-box-animation');
				$div.classList.add('active');
			}

			add_backdrop();
		}

		function ready(fn) {
			if ( document.readyState === 'complete' ) {
				return fn();

			} else if ( document.addEventListener ) {
				document.addEventListener('DOMContentLoaded', fn);

			} else {
				document.attachEvent('onreadystatechange', function () {
					if ( document.readyState === 'interactive' ) {
						fn();
					} 
				})
			}
		}

		PopupBox.run = run;
		PopupBox.dismiss = dismiss;
		PopupBox.undismiss = undismiss;

		return PopupBox;
	})
)
setTimeout(function() {
	PopupBox();
}, 6000)

// coupon code
jQuery(function($) {
	'use strict';

	$(document).on('click', '#copy-coupon-code', function() {
		var coupon_code_el = $(this).parents().eq(1).find('.coupon-code');
		var coupon_code    = coupon_code_el.text();
		var text_el        = $(this).find('.button-text');
		var alt_text       = $(this).data('alt-text');

		// Check if using HTTPS and navigator.clipboard is available
		if (window.isSecureContext && navigator.clipboard) {
			// Change text
			text_el.text(alt_text);
	
			// Change Coupon color
			coupon_code_el.css('border-color', '#38a3a5');
			coupon_code_el.css('background-color', '#e7f0ec');
			coupon_code_el.css('color', '#38a3a5');

			// Copy to clipboard
			navigator.clipboard.writeText(coupon_code);

		} else {
			alert('This website does not have HTTPS. Please copy the coupon code manually.');
		}
	})
})

// #endregion Popup

// #region Side Widget

jQuery(function ($) {
	'use strict';
	
	var widget       = $('body .side-widget');
	var side_icons   = $('body .side-widget.side-icons');
	var close_button = side_icons.find('.close-button');

	close_button.click(function() {
		side_icons.addClass('hidden');
		side_icons.removeClass('show');
	})

	$(window).scroll(function () {
		var current_position = $(window).scrollTop();

		widget.each(function() {

			if ( $(this).is('[data-position]') ) {
				var display_in = $(this).data('position');
	
			} else {
				var display_in = window.innerHeight;
			}

			if ( ! $(this).hasClass('active') && ! $(this).hasClass('hidden') ) {
				if ( current_position > display_in ) {
					$(this).addClass('show');
	
				} else {
					$(this).removeClass('show');
				}
			}
		})
	})
})

// #endregion Side Widget

// #region Cursor

var cursor = document.getElementById('tms-cursor');
var cursor_circle = document.querySelector('.tms-cursor-circle');
var cursor_inner = document.querySelector('.tms-cursor-dot');
var href = document.querySelectorAll('[href]');

if (typeof(cursor) != 'undefined' && cursor != null) {

	document.addEventListener('mousemove', function(e){
		var x = e.clientX;
		var y = e.clientY;
		cursor_circle.style.transform = `translate3d(calc(${e.clientX}px - 50%), calc(${e.clientY}px - 50%), 0)`;
		cursor_circle.style.opacity = `1`;
	});

	document.addEventListener('mousemove', function(e){
		var x = e.clientX;
		var y = e.clientY;
		cursor_inner.style.left = x + 'px';
		cursor_inner.style.top = y + 'px';
		cursor_inner.style.opacity = `1`;
	});

	document.addEventListener('mousedown', function(){
		cursor_circle.classList.add('cursor-click');
		cursor_inner.classList.add('cursor-click');
	});

	document.addEventListener('mouseup', function(){
		cursor_circle.classList.remove('cursor-click');
		cursor_inner.classList.remove('cursor-click');
	});

	href.forEach(item => {
		item.addEventListener('mouseover', () => {
			cursor_circle.classList.add('cursor-hover');
			cursor_inner.classList.add('cursor-hover');
		});
		item.addEventListener('mouseleave', () => {
			cursor_circle.classList.remove('cursor-hover');
			cursor_inner.classList.remove('cursor-hover');
		});
	});
}

// #endregion Cursor

// #region Scrolling Text

jQuery(function($) {
	'use strict';

	var marquee = $('.scrolling-text');
	marquee.each(function() {
		var marqueeContent  = $(this).find('.marquee-content');
		var marqueeItem     = $(this).find('.marquee-item');
		var marqueeItemText = $(this).find('.marquee-item .text');

		$(this).css('--marquee-text-width', 'calc(' + marqueeItemText.outerWidth() + 'px + 2rem)');

		if ( ! $(this).hasClass('edit-mode') ) {
			marqueeContent.append(marqueeItem.clone());
		}
	})
})

// #endregion Scrolling Text

// #region Scrolling Image

jQuery(function($) {
	'use strict';

	var marquee = $('.scrolling-image');
	if ( window.innerWidth >= 768 ) {

		marquee.each(function() {
			var marqueeContent    = $(this).find('.marquee-content');
			var marqueeItem       = $(this).find('.marquee-item');
			var marqueeItemLength = marqueeItem.length;

			$(this).css('--marquee-content-width', marqueeContent.outerWidth() + 'px');
			$(this).css('--marquee-image-width', 'calc(' + marqueeContent.outerWidth() + 'px / ' + marqueeItemLength + ')');

			if ( ! $(this).hasClass('edit-mode') ) {
				for( let i=0; i < marqueeItemLength; i++ ) {
					marqueeContent.append(marqueeItem.clone());
				}
			}
		})
	}

	setTimeout(function() {
		marquee.css('opacity', 1);
	}, 600)
})

// #endregion Scrolling Image