/*----------------------------------------------

[Menu Engine JavaScript]

Theme   : Gomax
Version : 1.0.0
Author  : Themeasy
Support : https://themeasy.co

----------------------------------------------*/

/*----------------------------------------------

[Content Index]

1. Main
2. Helper

----------------------------------------------*/

/*----------------------------------------------
1. Main
----------------------------------------------*/

// #region Main

// Display the dropdown
function show_menu(everyitem) {
	let el_link = everyitem.querySelector('a[data-bs-toggle]');
	let el_btn  = everyitem.querySelector('.btn[data-bs-toggle]');
	
	if (el_btn) { el_link = el_btn; }

	if (el_link != null) {
		let nextEl = el_link.nextElementSibling;

		if (nextEl.classList.contains('dropdown-menu')) {
			el_link.classList.add('show');
 			nextEl.classList.add('show');
		}
	}
}

// Hide the dropdown
function hide_menu(everyitem) {
	let el_link = everyitem.querySelector('a[data-bs-toggle]');
	let el_btn  = everyitem.querySelector('.btn[data-bs-toggle]');
	
	if (el_btn) { el_link = el_btn; }
	
	if (el_link != null) {
		let nextEl = el_link.nextElementSibling;
		
		if (nextEl.classList.contains('dropdown-menu')) {
			el_link.classList.remove('show');
 			nextEl.classList.remove('show');
		}	
	}
}

// Enable dark screen element
function darken_activate() {
	el_overlay = document.createElement('span');
	el_overlay.className = 'screen-darken active';
	document.body.appendChild(el_overlay);
}

// Remove dark screen element
function darken_remove() {
	el_overlay = document.querySelector('.screen-darken');
	el_overlay.classList.remove('active');
	// document.body.removeChild(document.querySelector('.screen-darken'));
}

// Toggles the display of the next element
function toggle_next_el(nextEl) {
	if (nextEl.style.display == 'contents') {
		nextEl.style.display = 'none';
		
	} else {
		nextEl.style.display = 'contents';
	}
}

//Performs actions necessary for the general functioning of the navbar
document.addEventListener('DOMContentLoaded', function() {

	// Build classes for the navbar when scrolling the page
	el_navbar = document.querySelector('.navbar.smart-scroll, .navbar.fixed-scroll');

	if (el_navbar) {
		var last_scroll_top = 0;

		window.addEventListener('scroll', function() {
			
			if (window.scrollY > 600) {
				el_navbar.classList.add('navbar-sticky');
		
			} else {
				el_navbar.classList.remove('navbar-sticky');
			} 

			if ( window.scrollY > 100 ) {

				if (window.scrollY < last_scroll_top) {
					el_navbar.classList.remove('scrolled-down');
					el_navbar.classList.add('scrolled-up');

				} else {
					el_navbar.classList.remove('scrolled-up');
					el_navbar.classList.add('scrolled-down');
				}

				last_scroll_top = window.scrollY;

			} else {
				el_navbar.classList.remove('scrolled-up', 'scrolled-down');
			}
		}) 
	}	
      
	// Prevent closing from click inside dropdown
	document.querySelectorAll('.dropdown-menu').forEach(function(element) {
		element.addEventListener('click', function (e) {
		  e.stopPropagation();
		})
	})

	// Function only performed on larger screens.
  if (window.innerWidth > 991) {
    
    // Dropdown hover
		document.querySelectorAll('.dropdown').forEach(function(everyitem) {
			everyitem.addEventListener('mouseenter', function() {
				if (everyitem.classList.contains('hover')) {
					show_menu(everyitem);
				}
				if (everyitem.classList.contains('hover') && everyitem.classList.contains('darken-on-show')) {
					darken_activate();
				}
			})
			everyitem.addEventListener('mouseleave', function() {
				if (everyitem.classList.contains('hover')) {
					hide_menu(everyitem);
				}
				if (everyitem.classList.contains('hover') && document.querySelector('.screen-darken')) {
					darken_remove();
				}
			})
		})

		// Dropdown click
	  document.querySelectorAll('.dropdown').forEach(function(everydropdown) {
			everydropdown.addEventListener('shown.bs.dropdown', function() {
				if (everydropdown.classList.contains('darken-on-show')) {
					darken_activate();
				}
			})
			everydropdown.addEventListener('hide.bs.dropdown', function() {
				if (document.querySelector('.screen-darken')) {
					darken_remove();
				}
			})
		})	
  }

	//Function only performed on smaller screens.
	if (window.innerWidth < 991) {

		// Close all inner dropdowns when parent is closed
		document.querySelectorAll('.dropdown').forEach(function(everydropdown) {
			everydropdown.addEventListener('hidden.bs.dropdown', function() {
				this.querySelectorAll('.megasubmenu, .submenu').forEach(function(everysubmenu) {
					everysubmenu.style.display = 'none';
				})
			})
		})

		// Adaptation of the dropdown in responsive mode
		document.querySelectorAll('.dropdown-menu a').forEach(function(element) {
			element.addEventListener('click', function (e) {
				let nextEl = this.nextElementSibling;
				if (nextEl && nextEl.classList.contains('submenu')) {	
					e.preventDefault();
					toggle_next_el(nextEl);
				}
			})
		})

		// Adaptation of the megamenu in responsive mode
		document.querySelectorAll('.has-megasubmenu > a').forEach(function(element) {			
			element.addEventListener('click', function (e) {
				let nextEl = this.nextElementSibling;
				if (nextEl && nextEl.classList.contains('megasubmenu')) {
					e.preventDefault();	
					toggle_next_el(nextEl);
				}
			})
		})
	}
})

// #endregion Main

/*----------------------------------------------
2. Helper
----------------------------------------------*/

// #region Helper

// Adjust navbar when WordPress toolbar is active. 
jQuery(function($) {
  'use strict';

  let body       = $('body');
  let navbar     = $('#navbar');
  let adminbar   = $('.admin-bar #wpadminbar');
  let adminbar_h = adminbar.height();

  if ( body.hasClass('admin-bar') && navbar.hasClass('smart-scroll') || navbar.hasClass('fixed-scroll') ) {
    adminbar.css('position', 'absolute');
    navbar.css('top', adminbar_h + 'px');
  } 
})

// Adjusts the spacing of the main section relative to the navbar height.
jQuery(function($) {
  'use strict';

  let navbar        = $('#navbar');
  let navbar_height = navbar.height();
  let main_section  = $('#main');

  if ( ! navbar.hasClass('navbar-transparent') ) {
    main_section.css('padding-top', navbar_height + 'px');
  } 
})

// Changes the side of the dropdown if it is stacked on the right side.
jQuery(function($) {
  'use strict';

  var screen_width = window.innerWidth;

  $('.dropdown-menu.submenu').each(function() {
    let offset_left = $(this).offset().left;

    if ( screen_width - offset_left <= 200 ) {
      $(this).addClass('submenu-left');

    } else {
      $(this).removeClass('submenu-left');
    }
  })
})

// Adjust the side image according to the megamenu.
jQuery(function($) {
	'use strict';
	
	// Side image menu item
	var side_image = $('.has-side-image');

	side_image.each(function(index) {

		// Just one of the images
		if (index === 0) {
			$(this).addClass('image-absolute-right');
			
			var absolute_image = $('.image-absolute-right');

			// Section
			var section = absolute_image.parents().eq(7);

			// Elementor Class
			var id_class = absolute_image.parents().eq(6).attr('class').replace('elementor ', '');
			var el_class = absolute_image.parents().eq(1).attr('class').replace('elementor-widget ', '').replace('elementor-widget-themeasy-megamenu-image', '');

			// Width
			var megamenu_width     = $('.navbar .megamenu').width();
			var container_width    = $('.navbar .megamenu .container').width();
			var column_width       = absolute_image.parents().eq(3).width();
			var column_inner_width = absolute_image.parents().eq(1).width();

			// Count
			var column_gap = ( column_width - column_inner_width ) / 2;
			var wrap_diff  = ( megamenu_width - container_width ) / 2;
			var new_width  = ( column_width + wrap_diff - column_gap ) - 30;

			// Apply
			if ( window.innerWidth > 991 ) {
				absolute_image.remove();
				absolute_image.appendTo( section );
				absolute_image.css( 'width', new_width );
				absolute_image.parents().eq(2).addClass(id_class);
				absolute_image.parents().eq(0).addClass(el_class);            
			}

		} else {
			$(this).removeClass('has-side-image');
		}
	})
})

// Adjust navbar positioning when offcanvas is triggered.
jQuery(function($) {
	'use strict';

	if (window.innerWidth > 991) {

		var navbar = $('#navbar');
		var offcanvas = $('.offcanvas');

		if ( navbar.hasClass('smart-scroll') || navbar.hasClass('fixed-scroll') ) {

			offcanvas.on('show.bs.offcanvas', function() {
				$('.navbar .container').css('position', 'relative');
				$('.navbar .container').css('right', '8.5px');
			})

			offcanvas.on('hidden.bs.offcanvas', function() {
				$('.navbar .container').css('position', '');
				$('.navbar .container').css('right', '');
			})
		}
	}
})

// Sets an optimal width for the megamenu if has categories menu.
jQuery(function($) {
  'use strict';
  
	if (window.innerWidth > 991) {
		const container = $('.navbar-bottom-fluid .container');
		const menu_item = $('.navbar-bottom-fluid .categories-menu');
		const megamenu  = $('.navbar-bottom-fluid .dropdown-menu .megamenu');
	
		// Calculates the viable size between the menu item and container.
		const width = ( container.width() - menu_item.width() );
	
		// Adds the width to the megamenu.
		megamenu.css( 'min-width', width + 'px' );

	} else {
		const section = $('.navbar-bottom-fluid');
		section.remove(); // The section is removed on mobile as it is displayed in the menu trigger.
	}
})

// Sets the links for the selected currency. Requires the WMC Currency plugin.
jQuery(function($) {
  'use strict';

  var lang_switcher = $('.currency-switcher');

  if ( lang_switcher.length > 0 ) {
    var current_url      = window.location.origin + location.pathname;
    var current_currency = (typeof wooMultiCurrencyParams !== 'undefined') ? wooMultiCurrencyParams.current_currency : null;

    
    if ( lang_switcher.length > 0 ) {
      var nav_link           = lang_switcher.find('.nav-link');
      var selected_item      = lang_switcher.find('> .nav-link .text');
      var selected_item_text = selected_item.text();

      if ( current_currency ) {
        nav_link.each(function() {
          var nav_item = $(this);
          var currency = nav_item.find('.text').text();

          if ( currency === current_currency ) {
            nav_item.find('.text').text( selected_item_text ); // Set new text to item in dropdown
          }
        })

        selected_item.text( current_currency ); // Set new text to selected item
      }

      // Set URL
      nav_link.each(function() {
        var nav_item = $(this);
        var currency = nav_item.find('.text').text();

        nav_item.attr('href', current_url + '?wmc-currency=' + currency);
      })

    }
  }
})

// Fixes the body and adjusts the overflow scrolling of a tall megamenu.
jQuery(function($) {
  'use strict';
  
	if ( window.innerWidth > 991 ) {
		const navbar = $('#navbar');
		const inner_section = $('.inner-section-expanded');

		inner_section.each(function() {
      // If the section height is greater than the screen height.
      if ( $(this).outerHeight() > window.innerHeight ) {

        // Adds the overflow to the section.
        $(this).css( 'height', 'calc( 100vh - '+navbar.height()+'px )' );
        $(this).css( 'overflow-y', 'auto' );
      }
		})
	}
})

// #endregion Helper