<?php
/**
 * Theme header where the template parts start.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.
?>
<!DOCTYPE html>

<html <?php language_attributes(); ?>>

<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width, initial-scale=1">
  <meta name="description" content="<?php bloginfo('description'); ?>">
  <?php wp_head(); ?>
</head>

<?php
/**
 * Check if dark mode is active and apply the body class.
 * 
 * @package Gomax
 * @since 1.0.0
 */
?>
<body <?php body_class(); ?>>
<?php 
wp_body_open();

/**
 * Enable site preloader.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( get_theme_mod( 'enable_preloader' ) ) {

  // Delay
  $delay = false;
  if ( get_theme_mod( 'preloader_delay' ) ) {
    $delay = get_theme_mod( 'preloader_delay' ) * 1000;

    if ( get_theme_mod( 'preloader_delay' ) === 0 ) {
      $delay = false;
    }
  }

  // Limit
  $limit = false;
  if ( get_theme_mod( 'preloader_limit' ) ) {
    $limit = get_theme_mod( 'preloader_limit' ) * 1000;

    if ( get_theme_mod( 'preloader_limit' ) === 0 ) {
      $limit = false;
    }
  }

  // Animation
  $animation = get_theme_mod( 'preloader_animation' );

  // Emblem
  $emblem = get_theme_mod( 'preloader_emblem' );

  // Render preloader
  printf(
    '<div id="preloader" class="preloader" data-staggerDelay="%s" data-limit="%s">%s</div>',
    esc_attr( $delay ),
    esc_attr( $limit ),
    sprintf(
      '<img src="%s" alt="%s" class="emblem %s" />',
      esc_url( $emblem ),
      get_bloginfo( 'name' ),
      esc_attr( $animation )
    )
  );
}

/**
 * Checks if there are global sections to display.
 * 
 * @package Gomax
 * @since 1.0.0
 */
$disable_header = get_post_meta( get_the_ID(), 'gomax_disable_header', true );

if ( gomax_has_core() && gomax_has_elementor() ) {

  if ( themeasy_before_header_enabled() ) {
    do_action( 'themeasy_before_header' );
  }

  if ( ! $disable_header ) {
    if ( themeasy_header_enabled() ) {
      do_action( 'themeasy_header' );

    } else {
      get_template_part( 'template-parts/header' );
    }
  }

} else {
  if ( ! $disable_header ) {
    get_template_part( 'template-parts/header' );
  }
}

/**
 * Enable smooth scroll.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( get_theme_mod( 'enable_smooth_scroll' ) ) :
  ?>
  <div id="smooth-scroll-viewport">
    <div id="smooth-scroll-content">
<?php endif; ?>