<?php
/**
 * Prepare the breadcrumb component.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

function gomax_breadcrumb() {

	// Get the title of the homepage.
	$front_page_id = get_option( 'page_on_front' );
	
	if ( $front_page_id != 0 ) {
		$front_page_title = get_the_title( $front_page_id );

	} else {
		$front_page_title =  get_bloginfo( 'name' );
	}

	// Check the title of the page and according to the type
	$page_title = gomax_get_page_title();
	?>
	<li class="breadcrumb-item">
		<a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="nofollow" class="breadcrumb-link">
			<span class="text"><?php echo esc_html( $front_page_title ); ?></span>
		</a>
	</li>
	<?php 
	if ( is_page() ) {
		global $post;
		$ancestors = get_post_ancestors( $post->ID );

		// Parent items
		if ( $ancestors ) {
			foreach ( array_reverse( $ancestors ) as $ancestor ) {
				$parent_title = get_the_title( $ancestor );
				$parent_link  = get_the_permalink( $ancestor );
				?>	
				<li class="breadcrumb-item">
					<a href="<?php echo esc_html( $parent_link ); ?>" rel="nofollow" class="breadcrumb-link">
					<span class="text"><?php echo esc_html( $parent_title ); ?></span>
					</a>
				</li>
			<?php
			}
		}
	}
	
	// Current item
	if ( ! is_front_page() && $page_title ) {		
		printf(
			'<li class="breadcrumb-item active">%s</li>',
			$page_title
		);
	} 
}

/**
 * Render the breadcrumb component.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_breadcrumb() {

	/**
	 * Checks if the breadcrumb is active.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	if ( get_theme_mod( 'disable_breadcrumb' ) ) {
		return;
	}

	// Don't show breadcrumb on WooCommerce empty cart page.
	if ( gomax_has_woocommerce() ) {		
		if ( is_cart() && WC()->cart->is_empty() || is_account_page() ) {
			return; 
		}
	}

	// Check the title of the page and according to the type
	$page_title = gomax_get_page_title();

	// Render breadcrumb
	if ( ! is_front_page() && $page_title ) {
		?>
		<div id="breadcrumb" class="breadcrumb-nav mb-3">
			<nav aria-label="breadcrumb">
				<ol class="breadcrumb">
					<?php gomax_breadcrumb(); ?>
				</ol>
			</nav>
			<?php
			/**
			 * Adds the login form toggle to WooCommerce checkout page.
			 * 
			 * @package Gomax
			 * @since 1.0.0
			 */
			if ( gomax_has_woocommerce() ) {
				if ( is_checkout() ) {
					do_action( 'woocommerce_login_form_toggle' );
				}
			}
			?>
		</div>
	<?php
	}
}