<?php
/**
 * Prepare the comments component.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

function gomax_get_post_comments() {
  // Display comments if they exist.
  if ( have_comments() ) {
    ?>
    <div id="comments" class="comments form-area needs-validation">
      <h4 class="title">
        <?php echo esc_html__( 'Comments', 'gomax' ) . ' (' . get_comments_number() . ')'; ?> 
      </h4>
      <ul class="comments-wrapper">
        <?php
        wp_list_comments( array(
          'avatar_size' 			=> 60, 
          'style'             => 'ul',
          'callback'          => 'gomax_comments_callback',
        ));
        ?>
      </ul>
      <?php
      the_comments_pagination( array( 
        'class' => 'pagination',
        'prev_text' => '<i class="fa-solid fa-arrow-left-long icon"></i>', 
        'next_text' => '<i class="fa-solid fa-arrow-right-long icon"></i>' 
      )); ?>
    </div>
    <?php 
  } 
  
  if ( comments_open() ) { 
    // Display comments if open. 
    ?>
    <div id="comment-form-wrapper" class="mt-3">
      <div class="comment-form form-area needs-validation">
        <?php 
        global $post;

        $post_id       = $post->ID;
        $commenter     = wp_get_current_commenter();
        $user          = wp_get_current_user();
        $user_identity = $user->exists() ? $user->display_name : '';
        $consent       = empty( $commenter['comment_author_email'] ) ? '' : 'checked';
        $required      = get_option( 'require_name_email' );

        $required_attribute = '';
        if ( $required ) {
          $required_attribute = 'required="required" aria-required="true"';
        }

        $args = array(
          'must_log_in' => sprintf(
            '<p class="must-log-in">%s</p>',
            sprintf(
              /* translators: %s: login URL. */
              esc_html__( 'You must be <a href="%s">logged in</a> to post a comment.', 'gomax' ),
              wp_login_url( apply_filters( 'the_permalink', get_permalink( $post_id ), $post_id ) )
            )
          ),
          'logged_in_as' => sprintf(
            '<p class="logged-in-as">%s%s</p>',
            sprintf(
              /* translators: 1: user name, 2: edit user link, 3: logout URL. */
              __( 'Logged in as %1$s. <a href="%2$s">Edit your profile</a>. <a href="%3$s">Log out?</a>', 'gomax' ),
              $user_identity,
              get_edit_user_link(),
              wp_logout_url( apply_filters( 'the_permalink', get_permalink( $post_id ), $post_id ) )
            ),
            '' /* $required_text removed here */ 
          ),
          'comment_notes_before' => sprintf(
            '<p class="comment-notes">%s%s</p>',
            sprintf(
              /* translators: 1: email notes */
              '<span id="email-notes">%s</span>',
              __( 'Your email address will not be published.', 'gomax' )
            ),
            '' /* $required_text removed here */ 
          ),
          'title_reply_before'  => '<h4 id="reply-title" class="title comment-reply-title">',
          'title_reply_after'   => '</h4>',
          'comment_field' => sprintf(
            '<div class="form-row row"><div class="form-col">%s</div></div>',
            sprintf(
              /* translators: 1: comment placeholder */
              '<textarea id="comment" class="form-control" name="comment" cols="45" rows="4" maxlength="65525" placeholder="%s" required="required" aria-required="true"></textarea>',
              esc_html__( 'Type your comment here ...', 'gomax' ) )
          ),
          'submit_button' => sprintf(
            '<div class="form-row row submit-button-row"><div class="form-col">%s</div></div>',
            sprintf(
            /* translators: 1: button text */
            '<button type="submit" id="submit" class="submit button">%s</button>',
            esc_html__( 'Post Comment', 'gomax' ) )
          ),
          'fields' => apply_filters( 'comment_form_default_fields', 
            array(
              'author' => sprintf(
                '<div class="form-row row"><div class="form-col">%s</div></div>',
                sprintf(
                  /* translators: 1: name value, 2: name placeholder, 3: required attribute */
                  '<input id="author" class="form-control" type="text" name="author" value="%s" size="30" maxlength="245" autocomplete="name" placeholder="%s" %s />',
                  esc_attr( $commenter['comment_author'] ),
                  esc_html__( 'Name', 'gomax' ),
                  ( $required ? $required_attribute : '' )
                )
              ),
              'email' => sprintf(
                '<div class="form-row row"><div class="form-col">%s</div></div>',
                sprintf(
                  /* translators: 1: email value, 2: email placeholder, 3: required attribute */
                  '<input id="email" class="form-control" type="email" name="email" value="%s" size="30" maxlength="100" autocomplete="email" placeholder="%s" %s />',
                  esc_attr( $commenter['comment_author_email'] ),
                  esc_html__( 'Email', 'gomax' ),
                  ( $required ? $required_attribute : '' )
                )
              ),
              'url' => sprintf(
                '<div class="form-row row"><div class="form-col">%s</div></div>',
                sprintf(
                  /* translators: 1: URL value, 2: URL placeholder, 3: required attribute */
                  '<input id="url" class="form-control" type="url" name="url" value="%s" size="30" maxlength="200" autocomplete="url" placeholder="%s" %s />',
                  esc_attr( $commenter['comment_author_url'] ),
                  esc_html__( 'Website', 'gomax' ),
                  ( $required ? $required_attribute : '' )
                )
              ),
              'cookies' => sprintf(
                '<div class="form-row row"><div class="form-col"><div class="form-check">%s</div></div></div>',
                sprintf(
                  /* translators: 1: checked attribute, 2: consent text */
                  '<input id="wp-comment-cookies-consent" class="form-check-input" type="checkbox" name="wp-comment-cookies-consent" value="Yes" %s />%s',
                  $consent,
                  sprintf(
                    /* translators: 1: consent text */
                    '<label class="form-label form-check-label" for="wp-comment-cookies-consent">%s</label>',
                    esc_html__( 'Save my name, email, and website in this browser for the next time I comment.', 'gomax' )
                  )
                )
              )
            )
          ) 
        );
        
        comment_form( $args );
        ?>
      </div>
    </div>
  <?php
  }
}

/**
 * Callback function that displays the comment.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_comments_callback( $comment, $args, $depth ) {
  // Displays if has comments.
  if ( $comment->comment_type === 'comment' ) {
    ?>
    <li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
      <div class="comment-wrapper">
        <div class="author-photo">
          <?php echo get_avatar( $comment, $args['avatar_size'], '', '', array( 'class' => array( 'image', 'shadow' ) ) ); ?>
        </div>
        <div class="comment-details">
          <div class="comment-author">
            <h4 class="author-name">
              <?php echo get_comment_author_link(); ?>
            </h4>         
          </div>
          <span class="comment-date">
						<i class="fa-regular fa-calendar icon"></i>
            <span class="text">
              <?php echo get_comment_date(); ?>
            </span>
          </span>
          <div class="comment-content">
            <?php comment_text(); ?>
            <?php if ( $comment->comment_approved == '0' ) : ?>
              <em><?php echo esc_html__( 'Comment awaiting approval.', 'gomax' ); ?></em>					
            <?php endif; ?>
          </div>
          <div class="comment-action">
            <?php
            $action_text  = '<i class="fa-solid fa-reply-all icon"></i>';
            $action_text .= '<span class="text">' . __( 'Reply', 'gomax' ) . '</span>';
      
            $comment_reply_link = get_comment_reply_link(
              array_merge( $args, array( 'reply_text' => $action_text, 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ),
              $comment->comment_ID
            );
      
            if ( $comment_reply_link ) {
              echo preg_replace( '/comment-reply-link/', 'comment-reply-link', $comment_reply_link, 1 );
            }

            if ( gomax_has_core() ) : ?>
              <i id="favorite-comment-<?php comment_ID() ?>" class="fa-solid fa-heart favorite-comment"></i>
            <?php endif; ?>
          </div>
        </div>
      </div>
    </li>
  <?php
  } else {
    $comment_label = __( 'Pingback:', 'gomax' );
    
    if ( $comment->comment_type === 'trackback' ) {
      $comment_label = __( 'Trackback:', 'gomax' );
    }
    ?>
    <li id="comment-<?php comment_ID() ?>" <?php comment_class( 'pingback-item' ); ?>>
      <?php echo esc_html( $comment_label ); ?> <?php comment_author_link(); ?> <?php edit_comment_link( __( 'Edit', 'gomax' ), '<span class="edit-link">', '</span>' ); ?>
    </li>
  <?php 
  }
}