<?php
/**
 * Prepare the post reference component.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

function gomax_get_post_reference() {

	/**
	 * Checks if the post reference is active.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	if ( get_theme_mod( 'disable_post_reference' ) ) {
		return;
	}

  /**
   * Checks if the post reference is active or there is content.
   * 
   * @package Gomax
   * @since 1.0.0
   */
  global $post;  
  if ( ! gomax_is_empty_content( $post->post_content ) ) {
    /**
     * Check if the author has description.
     * 
     * @package Gomax
     * @since 1.0.0
     */
    $description = get_the_author_meta( 'description' );
    if ( $description ) {
      ?>
      <div id="post-reference" class="mt-3 mb-3">
        <div class="post-reference">
          <div class="post-reference-container">
            <div class="image-wrapper">
              <img src="<?php echo esc_url( gomax_get_author_image() ); ?>" alt="Image name" class="author-photo">
            </div>
            <div class="text-wrapper">
              <?php 
              printf(
                '<h5 class="author-name">%s</h5>',
                sprintf(
                  '<a href="%s" target="_blank">%s</a>',
                  get_the_author_meta( 'user_url' ),
                  get_the_author_meta( 'display_name' )
                )
              );      
              printf(
                '<p class="description">%s</p>',
                esc_html( $description )
              );
              ?>
            </div>
          </div>
        </div>
      </div>
    <?php
    }
  }
}