<?php
/**
 * Prepare the categories and tags component.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

function gomax_get_post_taxonomy() {

  /**
   * Check post type and start taxonomies.
   * 
   * @package Gomax
   * @since 1.0.0
   */
  if ( is_singular( 'portfolio' ) ) {
    $categories   = get_the_terms( get_the_ID(), 'portfolio-category' );
    $tags         = get_the_terms( get_the_ID(), 'portfolio-tag' );

  } else {
    $categories   = get_the_category();
    $tags         = get_the_tags();
  }

  if ( ! get_theme_mod( 'disable_categories' ) && ! empty( $categories ) ) {
    ?>
    <div id="post-categories" class="post-categories mt-3 mb-3">
      <h4 class="title"><?php echo esc_html__( 'Categories', 'gomax' ) ; ?></h4>
      <div class="badge-wrapper">
        <?php foreach ( $categories as $category ) { ?>
          <a href="<?php echo get_category_link( $category->term_id ); ?>" class="badge">                      
            <span class="badge-text"><?php echo esc_html( $category->name ); ?></span>
          </a>
        <?php } ?>
      </div>
    </div>
  <?php
  }
  
  if ( ! get_theme_mod( 'disable_tags' ) && ! empty( $tags ) ) {
    ?>
    <div id="post-tags" class="mt-3 mb-3">
      <h4 class="title"><?php echo esc_html__( 'Tags', 'gomax' ) ; ?></h4>
      <div class="badge-wrapper">
        <?php foreach ( $tags as $tag ) { ?>
          <a href="<?php echo get_tag_link( $tag->term_id ); ?>" class="badge">                      
            <span class="badge-text"><?php echo esc_html( $tag->name ); ?></span>
          </a>
        <?php } ?>
      </div>
    </div>
  <?php
  }
}