<?php
/**
 * Prepare the sidebar component.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

/**
 * Checks if the sidebar is active.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_has_sidebar( $sidebar ) {
  global $template;

  // Does not show if it is disabled
  $disable_sidebar = get_post_meta( get_the_ID(), 'gomax_disable_sidebar', true );
  if ( $disable_sidebar ) {
    return false;
  }

  // Don't show sidebar on WooCommerce pages  
	if ( gomax_has_woocommerce() ) {		
		if ( is_product() || is_cart() || is_checkout() || is_account_page() ) {
			return false; 
		}
	}
  
  // Show sidebar only in the default, blog list, and portfolio list templates
  if ( basename( $template ) !== 'index.php' && basename( $template ) !== 'blog-list.php' && basename( $template ) !== 'portfolio-list.php' ) {
    return false;  
  }
  
  // Show sidebar if there are widgets in it
  if ( is_active_sidebar( $sidebar ) ) {
    return true;
    
  } else {
    return false;
  }
}

/**
 * Render the sidebar component.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_get_sidebar( $sidebar ) {
  $has_sidebar = gomax_has_sidebar( $sidebar );

  if ( $has_sidebar ) {
    ?>
    <div class="col-12 col-md-4">
      <aside class="sidebar-section wp-sidebar sticky-top">
        <?php dynamic_sidebar( $sidebar ); ?>
      </aside>
    </div>
  <?php
  }
}