<?php
/**
 * Contains methods for customizing the theme customization screen.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

class Gomax_Customize {

	/**
	 * Add new sections and controls to the Theme Customize screen.
	 * 
   * @package WordPress
	 * @since Gomax 1.0.0
	 */
	public static function register ( $wp_customize ) {

		$wp_customize->add_panel( 'gomax_theme_settings',
			array(
				'priority'   => 21, // Site Identity priority is 20
			 	'capability' => 'edit_theme_options',
			 	'title'      => __( 'Theme Settings', 'gomax' ),
			)
		);

		#region Color Scheme

		$wp_customize->remove_section( 'colors' );

		$wp_customize->add_section( 'gomax_color_scheme', 
			array(
				'title'       => __( 'Color Scheme', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Here you can choose all the colors that are part of the theme design. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);
		 
		$wp_customize->add_setting( 'primary_color',
			array(
				'default'    => '#3772ff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);      
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_primary_color',
			array(
				'label'    => __( 'Primary Color', 'gomax' ),
				'settings' => 'primary_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'secondary_color',
			array(
				'default'    => '#ff006e',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);      
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_secondary_color',
			array(
				'label'    => __( 'Secondary Color', 'gomax' ),
				'settings' => 'secondary_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'accent_color',
			array(
				'default'    => '#cddcff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_accent_color',
			array(
				'label'    => __( 'Accent Color', 'gomax' ),
				'settings' => 'accent_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'info_color',
			array(
				'default'    => '#3772ff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_info_color',
			array(
				'label'    => __( 'Info Color', 'gomax' ),
				'settings' => 'info_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'success_color',
			array(
				'default'    => '#38a3a5',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_success_color',
			array(
				'label'    => __( 'Success Color', 'gomax' ),
				'settings' => 'success_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'danger_color',
			array(
				'default'    => '#ff006e',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_danger_color',
			array(
				'label'    => __( 'Danger Color', 'gomax' ),
				'settings' => 'danger_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'black_color',
			array(
				'default'    => '#151515',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_black_color',
			array(
				'label'    => __( 'Black Color', 'gomax' ),
				'settings' => 'black_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'white_color',
			array(
				'default'    => '#ffffff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_white_color',
			array(
				'label'    => __( 'White Color', 'gomax' ),
				'settings' => 'white_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		 
		$wp_customize->add_setting( 'primary_bg_color',
			array(
				'default'    => '#ffffff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_primary_bg_color',
			array(
				'label'    => __( 'Primary Background Color', 'gomax' ),
				'settings' => 'primary_bg_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		
		$wp_customize->add_setting( 'secondary_bg_color',
			array(
				'default'    => '#f3f4f7',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_secondary_bg_color',
			array(
				'label'    => __( 'Secondary Background Color', 'gomax' ),
				'settings' => 'secondary_bg_color',
				'section'  => 'gomax_color_scheme',
			) 
		));

		$wp_customize->add_setting( 'primary_border_color',
			array(
				'default'    => '#f3f4f7',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_primary_border_color',
			array(
				'label'    => __( 'Primary Border Color', 'gomax' ),
				'settings' => 'primary_border_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		
		$wp_customize->add_setting( 'secondary_border_color',
			array(
				'default'    => '#151515',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_secondary_border_color',
			array(
				'label'    => __( 'Secondary Border Color', 'gomax' ),
				'settings' => 'secondary_border_color',
				'section'  => 'gomax_color_scheme',
			) 
		));

		$wp_customize->add_setting( 'primary_text_color',
			array(
				'default'    => '#495057',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_primary_text_color',
			array(
				'label'       => __( 'Primary Text Color', 'gomax' ),
				'description' => __( 'This color will be applied to the body of the site, such as paragraphs, plain text and other low-profile elements.', 'gomax' ),
				'settings'    => 'primary_text_color',
				'section'     => 'gomax_color_scheme',
			) 
		));
		
		$wp_customize->add_setting( 'secondary_text_color',
			array(
				'default'    => '#151515',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_secondary_text_color',
			array(
				'label'       => __( 'Secondary Text Color', 'gomax' ),
				'description' => __( 'This color will be applied to important elements such as headings, highlight texts and icons, among others.', 'gomax' ),
				'settings'    => 'secondary_text_color',
				'section'     => 'gomax_color_scheme',
			) 
		));

		$wp_customize->add_setting( 'primary_button_color',
			array(
				'default'    => '#151515',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_primary_button_color',
			array(
				'label'    => __( 'Primary Button Color', 'gomax' ),
				'description' => __( 'This color will be applied to the background and border of the buttons.', 'gomax' ),
				'settings' => 'primary_button_color',
				'section'  => 'gomax_color_scheme',
			) 
		));
		
		$wp_customize->add_setting( 'secondary_button_color',
			array(
				'default'    => '#ffffff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Color_Control(
			$wp_customize,
			'gomax_secondary_button_color',
			array(
				'label'    => __( 'Secondary Button Color', 'gomax' ),
				'description' => __( 'This color will be applied to button text and icons when available.', 'gomax' ),
				'settings' => 'secondary_button_color',
				'section'  => 'gomax_color_scheme',
			) 
		));

		#endregion Color Scheme

		#region Typography

		/**
		 * List of the 500 most popular Google Fonts.
		 * 
		 * @package WordPress
		 * @since Gomax 1.0.0
		 */
		$google_fonts = array(
			'Roboto, sans-serif' => 'Roboto',
			'Open Sans, sans-serif' => 'Open Sans',
			'Noto Sans JP, sans-serif' => 'Noto Sans JP',
			'Montserrat, sans-serif' => 'Montserrat',
			'Lato, sans-serif' => 'Lato',
			'Poppins, sans-serif' => 'Poppins',
			'Source Sans Pro, sans-serif' => 'Source Sans Pro',
			'Roboto Condensed, sans-serif' => 'Roboto Condensed',
			'Oswald, sans-serif' => 'Oswald',
			'Roboto Mono, monospace' => 'Roboto Mono',
			'Raleway, sans-serif' => 'Raleway',
			'Noto Sans, sans-serif' => 'Noto Sans',
			'Inter, sans-serif' => 'Inter',
			'Ubuntu, sans-serif' => 'Ubuntu',
			'Roboto Slab, serif' => 'Roboto Slab',
			'Mukta, sans-serif' => 'Mukta',
			'Nunito, sans-serif' => 'Nunito',
			'Merriweather, serif' => 'Merriweather',
			'PT Sans, sans-serif' => 'PT Sans',
			'Playfair Display, serif' => 'Playfair Display',
			'Rubik, sans-serif' => 'Rubik',
			'Nunito Sans, sans-serif' => 'Nunito Sans',
			'Noto Sans KR, sans-serif' => 'Noto Sans KR',
			'Work Sans, sans-serif' => 'Work Sans',
			'Lora, serif' => 'Lora',
			'Nanum Gothic, sans-serif' => 'Nanum Gothic',
			'Fira Sans, sans-serif' => 'Fira Sans',
			'Noto Serif, serif' => 'Noto Serif',
			'Quicksand, sans-serif' => 'Quicksand',
			'Barlow, sans-serif' => 'Barlow',
			'Noto Sans TC, sans-serif' => 'Noto Sans TC',
			'Titillium Web, sans-serif' => 'Titillium Web',
			'Mulish, sans-serif' => 'Mulish',
			'PT Serif, serif' => 'PT Serif',
			'Inconsolata, monospace' => 'Inconsolata',
			'Kanit, sans-serif' => 'Kanit',
			'Hind Siliguri, sans-serif' => 'Hind Siliguri',
			'IBM Plex Sans, sans-serif' => 'IBM Plex Sans',
			'Heebo, sans-serif' => 'Heebo',
			'Libre Franklin, sans-serif' => 'Libre Franklin',
			'Josefin Sans, sans-serif' => 'Josefin Sans',
			'Karla, sans-serif' => 'Karla',
			'DM Sans, sans-serif' => 'DM Sans',
			'Maven Pro, sans-serif' => 'Maven Pro',
			'Dosis, sans-serif' => 'Dosis',
			'Arimo, sans-serif' => 'Arimo',
			'Libre Baskerville, serif' => 'Libre Baskerville',
			'PT Sans Narrow, sans-serif' => 'PT Sans Narrow',
			'Oxygen, sans-serif' => 'Oxygen',
			'Source Code Pro, monospace' => 'Source Code Pro',
			'Bitter, serif' => 'Bitter',
			'Cabin, sans-serif' => 'Cabin',
			'Anton, sans-serif' => 'Anton',
			'Source Serif Pro, serif' => 'Source Serif Pro',
			'Cairo, sans-serif' => 'Cairo',
			'Dancing Script, handwriting' => 'Dancing Script',
			'Bebas Neue, display' => 'Bebas Neue',
			'M PLUS Rounded 1c, sans-serif' => 'M PLUS Rounded 1c',
			'EB Garamond, serif' => 'EB Garamond',
			'Manrope, sans-serif' => 'Manrope',
			'Barlow Condensed, sans-serif' => 'Barlow Condensed',
			'Lobster, display' => 'Lobster',
			'Hind, sans-serif' => 'Hind',
			'Abel, sans-serif' => 'Abel',
			'Prompt, sans-serif' => 'Prompt',
			'Signika Negative, sans-serif' => 'Signika Negative',
			'Comfortaa, display' => 'Comfortaa',
			'Fjalla One, sans-serif' => 'Fjalla One',
			'Varela Round, sans-serif' => 'Varela Round',
			'Exo 2, sans-serif' => 'Exo 2',
			'Crimson Text, serif' => 'Crimson Text',
			'Pacifico, handwriting' => 'Pacifico',
			'Overpass, sans-serif' => 'Overpass',
			'Merriweather Sans, sans-serif' => 'Merriweather Sans',
			'Arvo, serif' => 'Arvo',
			'Noto Sans SC, sans-serif' => 'Noto Sans SC',
			'Archivo, sans-serif' => 'Archivo',
			'Noto Serif JP, serif' => 'Noto Serif JP',
			'Teko, sans-serif' => 'Teko',
			'Secular One, sans-serif' => 'Secular One',
			'Asap, sans-serif' => 'Asap',
			'Hind Madurai, sans-serif' => 'Hind Madurai',
			'Abril Fatface, display' => 'Abril Fatface',
			'Shadows Into Light, handwriting' => 'Shadows Into Light',
			'Caveat, handwriting' => 'Caveat',
			'Assistant, sans-serif' => 'Assistant',
			'Rajdhani, sans-serif' => 'Rajdhani',
			'Jost, sans-serif' => 'Jost',
			'Questrial, sans-serif' => 'Questrial',
			'Indie Flower, handwriting' => 'Indie Flower',
			'Public Sans, sans-serif' => 'Public Sans',
			'Yanone Kaffeesatz, sans-serif' => 'Yanone Kaffeesatz',
			'Barlow Semi Condensed, sans-serif' => 'Barlow Semi Condensed',
			'Slabo 27px, serif' => 'Slabo 27px',
			'Zilla Slab, serif' => 'Zilla Slab',
			'Satisfy, handwriting' => 'Satisfy',
			'Fira Sans Condensed, sans-serif' => 'Fira Sans Condensed',
			'Cormorant Garamond, serif' => 'Cormorant Garamond',
			'IBM Plex Serif, serif' => 'IBM Plex Serif',
			'Red Hat Display, sans-serif' => 'Red Hat Display',
			'Catamaran, sans-serif' => 'Catamaran',
			'IBM Plex Mono, monospace' => 'IBM Plex Mono',
			'Space NeueHaas, sans-serif' => 'Space NeueHaas',
			'Tajawal, sans-serif' => 'Tajawal',
			'Nanum Myeongjo, serif' => 'Nanum Myeongjo',
			'Archivo Narrow, sans-serif' => 'Archivo Narrow',
			'Play, sans-serif' => 'Play',
			'Signika, sans-serif' => 'Signika',
			'Permanent Marker, handwriting' => 'Permanent Marker',
			'ABeeZee, sans-serif' => 'ABeeZee',
			'Domine, serif' => 'Domine',
			'Alfa Slab One, display' => 'Alfa Slab One',
			'Chakra Petch, sans-serif' => 'Chakra Petch',
			'Exo, sans-serif' => 'Exo',
			'Acme, sans-serif' => 'Acme',
			'Sarabun, sans-serif' => 'Sarabun',
			'Bree Serif, serif' => 'Bree Serif',
			'Amatic SC, handwriting' => 'Amatic SC',
			'Fredoka One, display' => 'Fredoka One',
			'Vollkorn, serif' => 'Vollkorn',
			'M PLUS 1p, sans-serif' => 'M PLUS 1p',
			'Righteous, display' => 'Righteous',
			'Alegreya, serif' => 'Alegreya',
			'Cinzel, serif' => 'Cinzel',
			'Frank Ruhl Libre, serif' => 'Frank Ruhl Libre',
			'Noto Sans HK, sans-serif' => 'Noto Sans HK',
			'Alegreya Sans, sans-serif' => 'Alegreya Sans',
			'DM Serif Display, serif' => 'DM Serif Display',
			'Russo One, sans-serif' => 'Russo One',
			'Tinos, serif' => 'Tinos',
			'Paytone One, sans-serif' => 'Paytone One',
			'Ubuntu Condensed, sans-serif' => 'Ubuntu Condensed',
			'Noto Sans Display, sans-serif' => 'Noto Sans Display',
			'Yantramanav, sans-serif' => 'Yantramanav',
			'Didact Gothic, sans-serif' => 'Didact Gothic',
			'Noto Sans Arabic, sans-serif' => 'Noto Sans Arabic',
			'Crete Round, serif' => 'Crete Round',
			'Francois One, sans-serif' => 'Francois One',
			'Courgette, handwriting' => 'Courgette',
			'Martel, serif' => 'Martel',
			'Archivo Black, sans-serif' => 'Archivo Black',
			'Amiri, serif' => 'Amiri',
			'Lobster Two, display' => 'Lobster Two',
			'Volkhov, serif' => 'Volkhov',
			'Prata, serif' => 'Prata',
			'Patua One, display' => 'Patua One',
			'Great Vibes, handwriting' => 'Great Vibes',
			'PT Sans Caption, sans-serif' => 'PT Sans Caption',
			'Baloo 2, display' => 'Baloo 2',
			'Kalam, handwriting' => 'Kalam',
			'Kaushan Script, handwriting' => 'Kaushan Script',
			'Antic Slab, serif' => 'Antic Slab',
			'Changa, sans-serif' => 'Changa',
			'Encode Sans, sans-serif' => 'Encode Sans',
			'Space Mono, monospace' => 'Space Mono',
			'Asap Condensed, sans-serif' => 'Asap Condensed',
			'Rokkitt, serif' => 'Rokkitt',
			'Noticia Text, serif' => 'Noticia Text',
			'Noto Kufi Arabic, sans-serif' => 'Noto Kufi Arabic',
			'Cardo, serif' => 'Cardo',
			'Spectral, serif' => 'Spectral',
			'Noto Serif TC, serif' => 'Noto Serif TC',
			'Passion One, display' => 'Passion One',
			'Yeseva One, display' => 'Yeseva One',
			'Cookie, handwriting' => 'Cookie',
			'Chivo, sans-serif' => 'Chivo',
			'Patrick Hand, handwriting' => 'Patrick Hand',
			'Old Standard TT, serif' => 'Old Standard TT',
			'Staatliches, display' => 'Staatliches',
			'Yellowtail, handwriting' => 'Yellowtail',
			'Sora, sans-serif' => 'Sora',
			'Cantarell, sans-serif' => 'Cantarell',
			'Cormorant, serif' => 'Cormorant',
			'Orbitron, sans-serif' => 'Orbitron',
			'Sawarabi Mincho, serif' => 'Sawarabi Mincho',
			'Almarai, sans-serif' => 'Almarai',
			'Faustina, serif' => 'Faustina',
			'Lexend Deca, sans-serif' => 'Lexend Deca',
			'Pathway Gothic One, sans-serif' => 'Pathway Gothic One',
			'Gothic A1, sans-serif' => 'Gothic A1',
			'Michroma, sans-serif' => 'Michroma',
			'Quattrocento Sans, sans-serif' => 'Quattrocento Sans',
			'Titan One, display' => 'Titan One',
			'Saira Condensed, sans-serif' => 'Saira Condensed',
			'Sacramento, handwriting' => 'Sacramento',
			'News Cycle, sans-serif' => 'News Cycle',
			'Concert One, display' => 'Concert One',
			'Unna, serif' => 'Unna',
			'Alata, sans-serif' => 'Alata',
			'Playfair Display SC, serif' => 'Playfair Display SC',
			'Josefin Slab, serif' => 'Josefin Slab',
			'Mali, handwriting' => 'Mali',
			'Montserrat Alternates, sans-serif' => 'Montserrat Alternates',
			'PT Mono, monospace' => 'PT Mono',
			'Mukta Malar, sans-serif' => 'Mukta Malar',
			'Gloria Hallelujah, handwriting' => 'Gloria Hallelujah',
			'Luckiest Guy, display' => 'Luckiest Guy',
			'Quattrocento, serif' => 'Quattrocento',
			'Philosopher, sans-serif' => 'Philosopher',
			'Lexend, sans-serif' => 'Lexend',
			'Gelasio, serif' => 'Gelasio',
			'Saira, sans-serif' => 'Saira',
			'Padauk, sans-serif' => 'Padauk',
			'Marcellus, serif' => 'Marcellus',
			'Cuprum, sans-serif' => 'Cuprum',
			'Press Start 2P, display' => 'Press Start 2P',
			'Advent Pro, sans-serif' => 'Advent Pro',
			'Bangers, display' => 'Bangers',
			'IBM Plex Sans Arabic, sans-serif' => 'IBM Plex Sans Arabic',
			'Poiret One, display' => 'Poiret One',
			'Ropa Sans, sans-serif' => 'Ropa Sans',
			'Alice, serif' => 'Alice',
			'Handlee, handwriting' => 'Handlee',
			'Taviraj, serif' => 'Taviraj',
			'Saira Semi Condensed, sans-serif' => 'Saira Semi Condensed',
			'Khand, sans-serif' => 'Khand',
			'Special Elite, display' => 'Special Elite',
			'Eczar, serif' => 'Eczar',
			'Noto Serif KR, serif' => 'Noto Serif KR',
			'Mitr, sans-serif' => 'Mitr',
			'Sawarabi Gothic, sans-serif' => 'Sawarabi Gothic',
			'Outfit, sans-serif' => 'Outfit',
			'Carter One, display' => 'Carter One',
			'Ultra, serif' => 'Ultra',
			'Ubuntu Mono, monospace' => 'Ubuntu Mono',
			'Crimson Pro, serif' => 'Crimson Pro',
			'El Messiri, sans-serif' => 'El Messiri',
			'Fira Sans Extra Condensed, sans-serif' => 'Fira Sans Extra Condensed',
			'Architects Daughter, handwriting' => 'Architects Daughter',
			'Be Vietnam Pro, sans-serif' => 'Be Vietnam Pro',
			'Viga, sans-serif' => 'Viga',
			'Vidaloka, serif' => 'Vidaloka',
			'Sen, sans-serif' => 'Sen',
			'Neuton, serif' => 'Neuton',
			'Encode Sans Condensed, sans-serif' => 'Encode Sans Condensed',
			'Commissioner, sans-serif' => 'Commissioner',
			'Aleo, serif' => 'Aleo',
			'Homemade Apple, handwriting' => 'Homemade Apple',
			'IBM Plex Sans Condensed, sans-serif' => 'IBM Plex Sans Condensed',
			'Parisienne, handwriting' => 'Parisienne',
			'Playball, display' => 'Playball',
			'Tangerine, handwriting' => 'Tangerine',
			'Lusitana, serif' => 'Lusitana',
			'Neucha, handwriting' => 'Neucha',
			'Istok Web, sans-serif' => 'Istok Web',
			'Bungee, display' => 'Bungee',
			'Noto Serif SC, serif' => 'Noto Serif SC',
			'Actor, sans-serif' => 'Actor',
			'Macondo, display' => 'Macondo',
			'Arsenal, sans-serif' => 'Arsenal',
			'Allura, handwriting' => 'Allura',
			'Cabin Condensed, sans-serif' => 'Cabin Condensed',
			'Hind Vadodara, sans-serif' => 'Hind Vadodara',
			'Fugaz One, display' => 'Fugaz One',
			'Ruda, sans-serif' => 'Ruda',
			'Creepster, display' => 'Creepster',
			'Sanchez, serif' => 'Sanchez',
			'Amaranth, sans-serif' => 'Amaranth',
			'Lilita One, display' => 'Lilita One',
			'Hammersmith One, sans-serif' => 'Hammersmith One',
			'Cousine, monospace' => 'Cousine',
			'Marck Script, handwriting' => 'Marck Script',
			'Monoton, display' => 'Monoton',
			'Gudea, sans-serif' => 'Gudea',
			'Khula, sans-serif' => 'Khula',
			'Nanum Gothic Coding, monospace' => 'Nanum Gothic Coding',
			'Rubik Mono One, sans-serif' => 'Rubik Mono One',
			'Alegreya Sans SC, sans-serif' => 'Alegreya Sans SC',
			'Urbanist, sans-serif' => 'Urbanist',
			'Oleo Script, display' => 'Oleo Script',
			'Sriracha, handwriting' => 'Sriracha',
			'Bai Jamjuree, sans-serif' => 'Bai Jamjuree',
			'Black Han Sans, sans-serif' => 'Black Han Sans',
			'Palanquin, sans-serif' => 'Palanquin',
			'Nanum Pen Script, handwriting' => 'Nanum Pen Script',
			'Kosugi Maru, sans-serif' => 'Kosugi Maru',
			'Rock Salt, handwriting' => 'Rock Salt',
			'Jura, sans-serif' => 'Jura',
			'Monda, sans-serif' => 'Monda',
			'Mr Dafoe, handwriting' => 'Mr Dafoe',
			'Stint Ultra Condensed, display' => 'Stint Ultra Condensed',
			'Quantico, sans-serif' => 'Quantico',
			'Gentium Book Basic, serif' => 'Gentium Book Basic',
			'Gruppo, display' => 'Gruppo',
			'Alef, sans-serif' => 'Alef',
			'Syncopate, sans-serif' => 'Syncopate',
			'Alex Brush, handwriting' => 'Alex Brush',
			'Adamina, serif' => 'Adamina',
			'Bodoni Moda, serif' => 'Bodoni Moda',
			'Mada, sans-serif' => 'Mada',
			'Plus Jakarta Sans, sans-serif' => 'Plus Jakarta Sans',
			'Sigmar One, display' => 'Sigmar One',
			'Literata, serif' => 'Literata',
			'Electrolize, sans-serif' => 'Electrolize',
			'Cantata One, serif' => 'Cantata One',
			'BenchNine, sans-serif' => 'BenchNine',
			'Laila, sans-serif' => 'Laila',
			'Bad Script, handwriting' => 'Bad Script',
			'Unica One, display' => 'Unica One',
			'Noto Sans Thai, sans-serif' => 'Noto Sans Thai',
			'Julius Sans One, sans-serif' => 'Julius Sans One',
			'Tenor Sans, sans-serif' => 'Tenor Sans',
			'Berkshire Swash, handwriting' => 'Berkshire Swash',
			'Caveat Brush, handwriting' => 'Caveat Brush',
			'Red Hat Text, sans-serif' => 'Red Hat Text',
			'Merienda, handwriting' => 'Merienda',
			'Fira Mono, monospace' => 'Fira Mono',
			'Black Ops One, display' => 'Black Ops One',
			'Armata, sans-serif' => 'Armata',
			'Lalezar, display' => 'Lalezar',
			'Damion, handwriting' => 'Damion',
			'Sorts Mill Goudy, serif' => 'Sorts Mill Goudy',
			'Abhaya Libre, serif' => 'Abhaya Libre',
			'Blinker, sans-serif' => 'Blinker',
			'Audiowide, display' => 'Audiowide',
			'DM Serif Text, serif' => 'DM Serif Text',
			'Pangolin, handwriting' => 'Pangolin',
			'Pontano Sans, sans-serif' => 'Pontano Sans',
			'Martel Sans, sans-serif' => 'Martel Sans',
			'Pragati Narrow, sans-serif' => 'Pragati Narrow',
			'Noto Naskh Arabic, serif' => 'Noto Naskh Arabic',
			'Economica, sans-serif' => 'Economica',
			'Basic, sans-serif' => 'Basic',
			'Itim, handwriting' => 'Itim',
			'Baskervville, serif' => 'Baskervville',
			'Forum, display' => 'Forum',
			'Shrikhand, display' => 'Shrikhand',
			'Varela, sans-serif' => 'Varela',
			'Nothing You Could Do, handwriting' => 'Nothing You Could Do',
			'Sintony, sans-serif' => 'Sintony',
			'Share Tech Mono, monospace' => 'Share Tech Mono',
			'Sarala, sans-serif' => 'Sarala',
			'Aclonica, sans-serif' => 'Aclonica',
			'Courier Prime, monospace' => 'Courier Prime',
			'Castoro, serif' => 'Castoro',
			'Ramabhadra, sans-serif' => 'Ramabhadra',
			'Niramit, sans-serif' => 'Niramit',
			'Rufina, serif' => 'Rufina',
			'Krub, sans-serif' => 'Krub',
			'Glegoo, serif' => 'Glegoo',
			'Karma, serif' => 'Karma',
			'Athiti, sans-serif' => 'Athiti',
			'Pridi, serif' => 'Pridi',
			'Palanquin Dark, sans-serif' => 'Palanquin Dark',
			'Kumbh Sans, sans-serif' => 'Kumbh Sans',
			'Anonymous Pro, monospace' => 'Anonymous Pro',
			'Rozha One, serif' => 'Rozha One',
			'Covered By Your Grace, handwriting' => 'Covered By Your Grace',
			'Coda, display' => 'Coda',
			'Arapey, serif' => 'Arapey',
			'Sansita, sans-serif' => 'Sansita',
			'Allerta, sans-serif' => 'Allerta',
			'Six Caps, sans-serif' => 'Six Caps',
			'K2D, sans-serif' => 'K2D',
			'Yrsa, serif' => 'Yrsa',
			'Average Sans, sans-serif' => 'Average Sans',
			'Cambay, sans-serif' => 'Cambay',
			'Lemonada, display' => 'Lemonada',
			'Reenie Beanie, handwriting' => 'Reenie Beanie',
			'Shadows Into Light Two, handwriting' => 'Shadows Into Light Two',
			'Antic, sans-serif' => 'Antic',
			'Libre Caslon Text, serif' => 'Libre Caslon Text',
			'PT Serif Caption, serif' => 'PT Serif Caption',
			'Cutive Mono, monospace' => 'Cutive Mono',
			'Jaldi, sans-serif' => 'Jaldi',
			'Italianno, handwriting' => 'Italianno',
			'Hind Guntur, sans-serif' => 'Hind Guntur',
			'Enriqueta, serif' => 'Enriqueta',
			'Fredericka the Great, display' => 'Fredericka the Great',
			'League Spartan, sans-serif' => 'League Spartan',
			'Noto Sans Tamil, sans-serif' => 'Noto Sans Tamil',
			'Reem Kufi, sans-serif' => 'Reem Kufi',
			'Changa One, display' => 'Changa One',
			'Pinyon Script, handwriting' => 'Pinyon Script',
			'Allerta Stencil, sans-serif' => 'Allerta Stencil',
			'Leckerli One, handwriting' => 'Leckerli One',
			'Cabin Sketch, display' => 'Cabin Sketch',
			'Darker Grotesque, sans-serif' => 'Darker Grotesque',
			'Antonio, sans-serif' => 'Antonio',
			'Saira Extra Condensed, sans-serif' => 'Saira Extra Condensed',
			'Kreon, serif' => 'Kreon',
			'Bowlby One SC, display' => 'Bowlby One SC',
			'Overlock, display' => 'Overlock',
			'Rancho, handwriting' => 'Rancho',
			'Fira Code, monospace' => 'Fira Code',
			'Gochi Hand, handwriting' => 'Gochi Hand',
			'Spinnaker, sans-serif' => 'Spinnaker',
			'Chewy, display' => 'Chewy',
			'Roboto Flex, sans-serif' => 'Roboto Flex',
			'Coming Soon, handwriting' => 'Coming Soon',
			'Alatsi, sans-serif' => 'Alatsi',
			'Arima Madurai, display' => 'Arima Madurai',
			'Kameron, serif' => 'Kameron',
			'Norican, handwriting' => 'Norican',
			'Readex Pro, sans-serif' => 'Readex Pro',
			'Short Stack, handwriting' => 'Short Stack',
			'Herr Von Muellerhoff, handwriting' => 'Herr Von Muellerhoff',
			'Londrina Solid, display' => 'Londrina Solid',
			'Capriola, sans-serif' => 'Capriola',
			'Gilda Display, serif' => 'Gilda Display',
			'Squada One, display' => 'Squada One',
			'Comic Neue, handwriting' => 'Comic Neue',
			'Nanum Brush Script, handwriting' => 'Nanum Brush Script',
			'Candal, sans-serif' => 'Candal',
			'Pattaya, sans-serif' => 'Pattaya',
			'Racing Sans One, display' => 'Racing Sans One',
			'Mrs Saint Delafield, handwriting' => 'Mrs Saint Delafield',
			'Annie Use Your Telescope, handwriting' => 'Annie Use Your Telescope',
			'Miriam Libre, sans-serif' => 'Miriam Libre',
			'VT323, monospace' => 'VT323',
			'Boogaloo, display' => 'Boogaloo',
			'Suez One, serif' => 'Suez One',
			'Graduate, display' => 'Graduate',
			'Bevan, display' => 'Bevan',
			'Source Sans 3, sans-serif' => 'Source Sans 3',
			'Biryani, sans-serif' => 'Biryani',
			'Holtwood One SC, serif' => 'Holtwood One SC',
			'Jua, sans-serif' => 'Jua',
			'Delius, handwriting' => 'Delius',
			'Epilogue, sans-serif' => 'Epilogue',
			'Sniglet, display' => 'Sniglet',
			'Telex, sans-serif' => 'Telex',
			'Aldrich, sans-serif' => 'Aldrich',
			'BioRhyme, serif' => 'BioRhyme',
			'Niconne, handwriting' => 'Niconne',
			'Amita, handwriting' => 'Amita',
			'Big Shoulders Display, display' => 'Big Shoulders Display',
			'David Libre, serif' => 'David Libre',
			'Mate, serif' => 'Mate',
			'Carrois Gothic, sans-serif' => 'Carrois Gothic',
			'Corben, display' => 'Corben',
			'Cinzel Decorative, display' => 'Cinzel Decorative',
			'Markazi Text, serif' => 'Markazi Text',
			'Just Another Hand, handwriting' => 'Just Another Hand',
			'Caudex, serif' => 'Caudex',
			'Fraunces, serif' => 'Fraunces',
			'Rye, display' => 'Rye',
			'Overpass Mono, monospace' => 'Overpass Mono',
			'Voltaire, sans-serif' => 'Voltaire',
			'Proza Libre, sans-serif' => 'Proza Libre',
			'Judson, serif' => 'Judson',
			'Manjari, sans-serif' => 'Manjari',
			'Mandali, sans-serif' => 'Mandali',
			'Source Serif 4, serif' => 'Source Serif 4',
			'Arizonia, handwriting' => 'Arizonia',
			'Oranienbaum, serif' => 'Oranienbaum',
			'JetBrains Mono, monospace' => 'JetBrains Mono',
			'Days One, sans-serif' => 'Days One',
			'Balsamiq Sans, display' => 'Balsamiq Sans',
			'Belleza, sans-serif' => 'Belleza',
			'Rambla, sans-serif' => 'Rambla',
			'Lateef, serif' => 'Lateef',
			'Scada, sans-serif' => 'Scada',
			'Quintessential, handwriting' => 'Quintessential',
			'Charm, handwriting' => 'Charm',
			'Contrail One, display' => 'Contrail One',
			'Zen Maru Gothic, sans-serif' => 'Zen Maru Gothic',
			'Shippori Mincho, serif' => 'Shippori Mincho',
			'Average, serif' => 'Average',
			'Oleo Script Swash Caps, display' => 'Oleo Script Swash Caps',
			'Fresca, sans-serif' => 'Fresca',
			'Marcellus SC, serif' => 'Marcellus SC',
			'Trocchi, serif' => 'Trocchi',
			'Podkova, serif' => 'Podkova',
			'Caladea, serif' => 'Caladea',
			'Chonburi, display' => 'Chonburi',
			'Rochester, handwriting' => 'Rochester',
			'Kristi, handwriting' => 'Kristi',
			'Halant, serif' => 'Halant',
			'Arbutus Slab, serif' => 'Arbutus Slab',
			'Noto Sans Devanagari, sans-serif' => 'Noto Sans Devanagari',
			'Calistoga, display' => 'Calistoga',
			'Bubblegum Sans, display' => 'Bubblegum Sans',
			'La Belle Aurore, handwriting' => 'La Belle Aurore',
			'Nixie One, display' => 'Nixie One',
			'Rammetto One, display' => 'Rammetto One',
			'Noto Sans Malayalam, sans-serif' => 'Noto Sans Malayalam',
			'Trirong, serif' => 'Trirong',
			'Mukta Vaani, sans-serif' => 'Mukta Vaani',
			'Atkinson Hyperlegible, sans-serif' => 'Atkinson Hyperlegible',
			'Do Hyeon, sans-serif' => 'Do Hyeon',
			'Libre Barcode 39, display' => 'Libre Barcode 39',
			'Yesteryear, handwriting' => 'Yesteryear',
			'Syne, sans-serif' => 'Syne',
			'Knewave, display' => 'Knewave',
			'Henny Penny, display' => 'Henny Penny',
			'Lustria, serif' => 'Lustria',
			'Magra, sans-serif' => 'Magra',
			'Cormorant Infant, serif' => 'Cormorant Infant',
			'Seaweed Script, display' => 'Seaweed Script',
			'GFS Didot, serif' => 'GFS Didot',
			'Alegreya SC, serif' => 'Alegreya SC',
			'STIX Two Text, serif' => 'STIX Two Text',
			'Nobile, sans-serif' => 'Nobile',
			'DM Mono, monospace' => 'DM Mono',
			'Suranna, serif' => 'Suranna',
			'Livvic, sans-serif' => 'Livvic',
			'Noto Sans Mono, monospace' => 'Noto Sans Mono',
			'Coustard, serif' => 'Coustard',
			'Mallanna, sans-serif' => 'Mallanna',
		);
		asort( $google_fonts );

		$wp_customize->add_section( 'gomax_typography', 
			array(
				'title'       => __( 'Typography', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'You can select one of Theme Presets or choose from over 500+ Google Fonts to compose the typography. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'font_mode',
			array(
				'default'    => 'theme-defaults',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_font_mode',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'theme-defaults' => 'Theme Defaults',
					'google-fonts' => 'Google Fonts', 
				),
				'label'       => __( 'Font Family Mode', 'gomax' ),
				'settings'    => 'font_mode',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'font_family_preset',
			array(
				'default'    				=> '1',
				'type'       				=> 'theme_mod',
				'capability'				=> 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value'
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_font_family_preset',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'1' 				=> 'Preset 1',
					'2' 				=> 'Preset 2',
					'3' 				=> 'Preset 3',
				),
				'label'       => __( 'Font Family Preset', 'gomax' ),
				'description' => __( 'Choose from the theme predefined font family options.', 'gomax' ),
				'settings'    => 'font_family_preset',
				'section'     => 'gomax_typography',
				// Condition
				'active_callback' => function ( $control ) {
					return $control->manager->get_setting( 'font_mode' )->value() === 'theme-defaults';
				}
			)
		));

    $wp_customize->add_setting( 'google_primary_font',
			array(
				'default'    => 'Lato, sans-serif',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_google_primary_font',
			array(
				'type'     		=> 'select',
				'choices'  		=> $google_fonts,
				'label'    		=> __( 'Primary Font', 'gomax' ),
				'description' => __( 'Applied to the body of the site, headings, paragraphs, plain text and other low-profile elements.', 'gomax' ),
				'settings' 		=> 'google_primary_font',
				'section'  		=> 'gomax_typography',
				// Condition
				'active_callback' => function ( $control ) {
					return $control->manager->get_setting( 'font_mode' )->value() === 'google-fonts';
				}
			)
		));

    $wp_customize->add_setting( 'google_secondary_font',
			array(
				'default'    => 'Lato, sans-serif',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_google_secondary_font',
			array(
				'type'     		=> 'select',
				'choices'  		=> $google_fonts,
				'label'    		=> __( 'Secondary Font', 'gomax' ),
				'description' => __( 'Applied to important elements such as display headings, highlight texts, among others.', 'gomax' ),
				'settings' 		=> 'google_secondary_font',
				'section'  		=> 'gomax_typography',
				// Condition
				'active_callback' => function ( $control ) {
					return $control->manager->get_setting( 'font_mode' )->value() === 'google-fonts';
				}
			)
		));

    $wp_customize->add_setting( 'body_font_size',
			array(
				'default'    => '1',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_body_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'Body Font Size', 'gomax' ),
				'settings'    => 'body_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'body_font_weight',
			array(
				'default'    => '400',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_body_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'Body Font Weight', 'gomax' ),
				'settings'    => 'body_font_weight',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'h1_font_size',
			array(
				'default'    => '2.5',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h1_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'H1 Font Size', 'gomax' ),
				'settings'    => 'h1_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'h1_font_weight',
			array(
				'default'    => '600',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h1_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'H1 Font Weight', 'gomax' ),
				'settings'    => 'h1_font_weight',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'h2_font_size',
			array(
				'default'    => '2',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h2_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'H2 Font Size', 'gomax' ),
				'settings'    => 'h2_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'h2_font_weight',
			array(
				'default'    => '600',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h2_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'H2 Font Weight', 'gomax' ),
				'settings'    => 'h2_font_weight',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'h3_font_size',
			array(
				'default'    => '1.75',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h3_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'H3 Font Size', 'gomax' ),
				'settings'    => 'h3_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'h3_font_weight',
			array(
				'default'    => '600',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h3_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'H3 Font Weight', 'gomax' ),
				'settings'    => 'h3_font_weight',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'h4_font_size',
			array(
				'default'    => '1.5',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h4_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'H4 Font Size', 'gomax' ),
				'settings'    => 'h4_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'h4_font_weight',
			array(
				'default'    => '600',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h4_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'H4 Font Weight', 'gomax' ),
				'settings'    => 'h4_font_weight',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'h5_font_size',
			array(
				'default'    => '1.2',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h5_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'H5 Font Size', 'gomax' ),
				'settings'    => 'h5_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'h5_font_weight',
			array(
				'default'    => '600',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h5_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'H5 Font Weight', 'gomax' ),
				'settings'    => 'h5_font_weight',
				'section'     => 'gomax_typography',
			)
		));

    $wp_customize->add_setting( 'h6_font_size',
			array(
				'default'    => '1',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h6_font_size',
			array(
				'type'        => 'number',
				'label'       => __( 'H6 Font Size', 'gomax' ),
				'settings'    => 'h6_font_size',
				'section'     => 'gomax_typography',
				'input_attrs' => array( 'min' => 1, 'max' => 20, 'step' => 0.1 )
			)
		));

    $wp_customize->add_setting( 'h6_font_weight',
			array(
				'default'    => '600',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_h6_font_weight',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'100' => '100', 
					'200' => '200', 
					'300' => '300', 
					'400' => '400', 
					'500' => '500', 
					'600' => '600', 
					'700' => '700', 
					'800' => '800', 
					'900' => '900' 
				),
				'label'       => __( 'H6 Font Weight', 'gomax' ),
				'settings'    => 'h6_font_weight',
				'section'     => 'gomax_typography',
			)
		));

		#endregion Typography

		#region Layout

		$wp_customize->add_section( 'gomax_layout', 
			array(
				'title'       => __( 'Layout', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Adjust website layout on different screen sizes. Save the changes and visit the site for a better view. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'container_width_1800',
			array(
				'default' => '1760',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1800',
			array(
				'type'        => 'number',
				'label'       => __( 'Monitor Extra Large', 'gomax' ),
				'description' => __( 'Width for screens larger than 1800px', 'gomax' ),
				'settings'    => 'container_width_1800',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1800, 'step' => 20 )
			)
		));

    $wp_customize->add_setting( 'container_width_1700',
			array(
				'default' => '1400',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1700',
			array(
				'type'        => 'number',
				'label'       => __( 'Monitor Large', 'gomax' ),
				'description' => __( 'Width for screens larger than 1700px', 'gomax' ),
				'settings'    => 'container_width_1700',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1700, 'step' => 20 )
			)
		));

    $wp_customize->add_setting( 'container_width_1600',
			array(
				'default' => '1400',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1600',
			array(
				'type'        => 'number',
				'label'       => __( 'Desktop Large', 'gomax' ),
				'description' => __( 'Width for screens larger than 1600px', 'gomax' ),
				'settings'    => 'container_width_1600',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1600, 'step' => 20 )
			)
		));

    $wp_customize->add_setting( 'container_width_1500',
			array(
				'default' => '1400',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1500',
			array(
				'type'        => 'number',
				'label'       => __( 'Desktop Medium', 'gomax' ),
				'description' => __( 'Width for screens larger than 1500px', 'gomax' ),
				'settings'    => 'container_width_1500',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1500, 'step' => 20 )
			)
		));

    $wp_customize->add_setting( 'container_width_1400',
			array(
				'default' => '1360',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1400',
			array(
				'type'        => 'number',
				'label'       => __( 'Laptop Large', 'gomax' ),
				'description' => __( 'Width for screens larger than 1400px', 'gomax' ),
				'settings'    => 'container_width_1400',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1400, 'step' => 20 )
			)
		));

    $wp_customize->add_setting( 'container_width_1300',
			array(
				'default' => '1260',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1300',
			array(
				'type'        => 'number',
				'label'       => __( 'Laptop Medium', 'gomax' ),
				'description' => __( 'Width for screens larger than 1300px', 'gomax' ),
				'settings'    => 'container_width_1300',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1300, 'step' => 20 )
			)
		));

    $wp_customize->add_setting( 'container_width_1200',
			array(
				'default' => '1160',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_container_width_1200',
			array(
				'type'        => 'number',
				'label'       => __( 'Laptop Small', 'gomax' ),
				'description' => __( 'Width for screens larger than 1200px', 'gomax' ),
				'settings'    => 'container_width_1200',
				'section'     => 'gomax_layout',
				'input_attrs' => array( 'min' => 768, 'max' => 1200, 'step' => 20 )
			)
		));

		#endregion Layout

		#region Options

		$wp_customize->add_section( 'gomax_options', 
			array(
				'title'       => __( 'Display Options', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Choose which native elements of the site pages you want to hide. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'disable_breadcrumb',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_disable_breadcrumb',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disable Breadcrumb', 'gomax' ),
				'description' => __( 'The breadcrumb appears horizontally above the content of the pages. This provides links back to each previous page the user navigated to.', 'gomax' ),
				'settings' => 'disable_breadcrumb',
				'section'  => 'gomax_options',
				)
			)
		);

    $wp_customize->add_setting( 'disable_post_navigation',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_disable_post_navigation',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disable Post Navigation', 'gomax' ),
				'description' => __( 'The post navigation appears next to the content of the pages. This provides links to the previous and next post.', 'gomax' ),
				'settings' => 'disable_post_navigation',
				'section'  => 'gomax_options',
				)
			)
		);

    $wp_customize->add_setting( 'disable_categories',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_disable_categories',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disable Categories', 'gomax' ),
				'description' => __( 'Categories appear next to page content in badge blocks. Each item links to the respective category archive page.', 'gomax' ),
				'settings' => 'disable_categories',
				'section'  => 'gomax_options',
				)
			)
		);

    $wp_customize->add_setting( 'disable_tags',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_disable_tags',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disable Tags', 'gomax' ),
				'description' => __( 'Tags appear next to page content in badge blocks. Each item links to the respective tag archive page.', 'gomax' ),
				'settings' => 'disable_tags',
				'section'  => 'gomax_options',
				)
			)
		);

    $wp_customize->add_setting( 'disable_post_reference',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_disable_post_reference',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disable Post Reference', 'gomax' ),
				'description' => __( 'The author block appears next to the page content. It contains the photo, name and biography of the author of the post.', 'gomax' ),
				'settings' => 'disable_post_reference',
				'section'  => 'gomax_options',
				)
			)
		);

    $wp_customize->add_setting( 'disable_post_metadata',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_disable_post_metadata',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disable Metadata', 'gomax' ),
				'description' => __( 'The post metadata appears under each item in the post listing. It contains date, author and link to comments.', 'gomax' ),
				'settings' => 'disable_post_metadata',
				'section'  => 'gomax_options',
				)
			)
		);

		#endregion Options

		#region Blog

		$wp_customize->add_section( 'gomax_blog', 
			array(
				'title'       => __( 'Blog', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Choose options to customize your blog style.. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'blog_columns',
			array(
				'default'    => '1',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_blog_columns',
			array(
				'type'    => 'select',
				'choices' => array( 
					'1' => '1', 
					'2' => '2', 
					'3' => '3', 
					'4' => '4', 
					'5' => '5', 
					'6' => '6'
				),
				'label'       => __( 'Columns', 'gomax' ),
				'settings'    => 'blog_columns',
				'section'     => 'gomax_blog',
			)
		));

		#endregion Blog

		#region Preloader

		$wp_customize->add_section( 'gomax_preloader', 
			array(
				'title'       => __( 'Preloader', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'Essentially, a preloader is the first piece of UI you see while waiting for your website to load. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'enable_preloader',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_enable_preloader',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Enable Preloader', 'gomax' ),
				'description' => __( 'When enabling the preloader choose your preferences below for this to work as expected. ', 'gomax' ),
				'settings' => 'enable_preloader',
				'section'  => 'gomax_preloader',
				)
			)
		);

    $wp_customize->add_setting( 'preloader_delay',
			array(
				'default' => '0',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_preloader_delay',
			array(
				'type'        => 'number',
				'label'       => __( 'Loading Delay', 'gomax' ),
				'description' => __( 'Value in seconds. ', 'gomax' ),
				'settings'    => 'preloader_delay',
				'section'     => 'gomax_preloader',
				'input_attrs' => array( 'min' => 1, 'max' => 100 )
			)
		));

    $wp_customize->add_setting( 'preloader_limit',
			array(
				'default' => '10',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_preloader_limit',
			array(
				'type'        => 'number',
				'label'       => __( 'Loading Limit', 'gomax' ),
				'description' => __( 'Value in seconds. ', 'gomax' ),
				'settings'    => 'preloader_limit',
				'section'     => 'gomax_preloader',
				'input_attrs' => array( 'min' => 1, 'max' => 100 )
			)
		));

    $wp_customize->add_setting( 'preloader_animation',
			array(
				'default'    				=> 'rotate-animation',
				'type'       				=> 'theme_mod',
				'capability'				=> 'edit_theme_options',
				'sanitize_callback' => 'sanitize_data_value'
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_preloader_animation',
			array(
				'type'     		=> 'select',
				'choices'  		=> array( 
					'rotate-animation' => 'Rotate',
					'scale-animation' => 'Scale',
					'no-animation' => 'None',
				),
				'label'       => __( 'Animation', 'gomax' ),
				'settings'    => 'preloader_animation',
				'section'     => 'gomax_preloader',
			)
		));

		$wp_customize->add_setting( 'preloader_emblem',
			array(
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
	
		$wp_customize->add_control( new WP_Customize_Image_Control ( $wp_customize, 'gomax_preloader_emblem',
			array(
				'label'    => __( 'Emblem', 'gomax' ),
				'description' => __( 'Choose an image to be displayed in the center of the loading screen. ', 'gomax' ),
				'settings' => 'preloader_emblem',
				'section'  => 'gomax_preloader',
			) 
		));

    $wp_customize->add_setting( 'preloader_emblem_width',
			array(
				'default' => '40',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_preloader_emblem_width',
			array(
				'type'        => 'number',
				'label'       => __( 'Emblem Width', 'gomax' ),
				'description' => __( 'Value in px', 'gomax' ),
				'settings'    => 'preloader_emblem_width',
				'section'     => 'gomax_preloader',
				'input_attrs' => array( 'min' => 1, 'max' => 500 )
			)
		));
		 
		$wp_customize->add_setting( 'preloader_background_color',
			array(
				'default'    => '#ffffff',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);      
		
		$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'gomax_preloader_background_color',
			array(
				'label'    => __( 'Background Color', 'gomax' ),
				'settings' => 'preloader_background_color',
				'section'  => 'gomax_preloader',
			) 
		));

		#endregion Preloader

		#region Smooth Scroll

		$wp_customize->add_section( 'gomax_smooth_scroll', 
			array(
				'title'       => __( 'Smooth Scroll (BETA)', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'This makes the page scrolling smoother. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'enable_smooth_scroll',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_enable_smooth_scroll',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Enable Smooth Scroll', 'gomax' ),
				'settings' => 'enable_smooth_scroll',
				'section'  => 'gomax_smooth_scroll',
				)
			)
		);

		#endregion Smooth Scroll

		#region Advanced

		$wp_customize->add_section( 'gomax_advanced', 
			array(
				'title'       => __( 'Advanced', 'gomax' ),
				'capability'  => 'edit_theme_options',
				'description' => __( 'These settings should be applied by advanced users, or upon instruction from your theme or plugin support. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
				'panel'				=> 'gomax_theme_settings',
			) 
		);

    $wp_customize->add_setting( 'enable_external_http_request',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_enable_external_http_request',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'External HTTP Request', 'gomax' ),
				'description' => __( 'Allows to change and allow external requests for the HTTP request.', 'gomax' ),
				'settings' => 'enable_external_http_request',
				'section'  => 'gomax_advanced',
				)
			)
		);

    $wp_customize->add_setting( 'disables_ssl_verification',
			array(
				'default'    => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_disables_ssl_verification',
			array(
				'type'     => 'checkbox',
				'label'    => __( 'Disables SSL verification', 'gomax' ),
				'description' => __( 'This filter modifies HTTP request arguments to bypass SSL verification when connecting to \'package.themeasy.co\'. It is useful for handling cases where SSL certificate issues might prevent successful communication with this server.', 'gomax' ),
				'settings' => 'disables_ssl_verification',
				'section'  => 'gomax_advanced',
				)
			)
		);

		#endregion Advanced

		#region Sticky Logo

		$wp_customize->add_setting( 'sticky_logo',
			array(
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);
		
		$wp_customize->add_control( new WP_Customize_Image_Control (
			$wp_customize,
			'gomax_sticky_logo',
			array(
				'label'    => __( 'Sticky Logo', 'gomax' ),
				'description' => __( 'Logo that will be displayed when the Navbar is scrolled down or up.', 'gomax' ),
				'settings' => 'sticky_logo',
				'section'  => 'title_tagline',
				'priority' => 8,
			) 
		));

		#endregion Sticky Logo

		#region Mobile Logo

		$wp_customize->add_setting( 'mobile_logo',
			array(
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);      
		
		$wp_customize->add_control( new WP_Customize_Image_Control (
			$wp_customize,
			'gomax_mobile_logo',
			array(
				'label'    => __( 'Mobile Logo', 'gomax' ),
				'description' => __( 'Logo will be displayed only on mobile devices.', 'gomax' ),
				'settings' => 'mobile_logo',
				'section'  => 'title_tagline',
				'priority' => 9,
			) 
		));

		#endregion Mobile Logo

		#region Logo Height

    $wp_customize->add_setting( 'logo_height',
			array(
				'default' => '38',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'absint',
			)
		);

		$wp_customize->add_control( new WP_Customize_Control(
			$wp_customize,
			'gomax_logo_height',
			array(
				'type'        => 'number',
				'label'       => __( 'Logo Height', 'gomax' ),
				'description' => __( 'Choose a value in pixels for the height of the logo image. The width of the logo is set automatically.', 'gomax' ),
				'settings'    => 'logo_height',
				'section'     => 'title_tagline',
				'priority'    => 9,
			)
		));

		#endregion Logo Height

		#region Additional JS

		$wp_customize->add_section( 'gomax_additional_js', 
			array(
				'title'       => __( 'Additional JS', 'gomax' ),
				'priority'    => 201,
				'capability'  => 'edit_theme_options',
				'description' => __( 'Add JavaScript code here to make any changes to the site. This is a feature for advanced users. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
			) 
		);

    $wp_customize->add_setting( 'additional_js',
			array(
				'default' => '',
				'type'       => 'theme_mod',
				'capability' => 'edit_theme_options',
				'transport'  => 'postMessage',
				'sanitize_callback' => 'sanitize_data_value',
			)
		);

		$wp_customize->add_control( new WP_Customize_Code_Editor_Control(
			$wp_customize,
			'gomax_additional_js',
			array(
				'code_type' => 'text/javascript',
				'label'     => __( 'Additional JS', 'gomax' ),
				'settings'  => 'additional_js',
				'section'   => 'gomax_additional_js',
				)
			)
		);

		#endregion Additional JS

		// WooCommerce controls are only added if the Themeasy plugin is active.
		if ( gomax_has_core() && gomax_has_woocommerce() ) {
			$wp_customize->remove_section( 'woocommerce_checkout' );

			#region Product Catalog
			
			$wp_customize->remove_control( 'woocommerce_shop_page_display' );
			$wp_customize->remove_control( 'woocommerce_default_catalog_orderby' );

			$wp_customize->add_setting( 'catalog_pagination_type',
				array(
					'default'    => 'ajax-pagination',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_catalog_pagination_type',
				array(
					'type'     		=> 'select',
					'choices'  		=> array( 
						'ajax-pagination' => __( 'Ajax Pagination', 'gomax' ),
						'load-more' => __( 'Load More Button', 'gomax' ),
						'infinite-scrolling' => __( 'Infinite Scrolling', 'gomax' ),
					),
					'label'       => __( 'Pagination Type', 'gomax' ),
					'description' => __( 'The pagination type is the control used to find more products on the page.', 'gomax' ),
					'settings'    => 'catalog_pagination_type',
					'section'     => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'catalog_order_by',
				array(
					'default'    => 'date',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_catalog_order_by',
				array(
					'type'     		=> 'select',
					'choices'  		=> array( 
						'title'         => __( 'Title', 'gomax' ),
						'price'         => __( 'Price', 'gomax' ),
						'sales'         => __( 'Sales', 'gomax' ),
						'ratings'       => __( 'Ratings', 'gomax' ),
						'comment_count' => __( 'Comment Count', 'gomax' ),
						'date'          => __( 'Date', 'gomax' ),
						'modified'      => __( 'Last Modified Date', 'gomax' ),
						'menu_order'    => __( 'Menu Order', 'gomax' ),
						'rand'          => __( 'Random', 'gomax' ),
						'none'          => __( 'None', 'gomax' ),
					),
					'label'       => __( 'Order by', 'gomax' ),
					'description' => __( 'Choose the default ordering of products.', 'gomax' ),
					'settings'    => 'catalog_order_by',
					'section'     => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'catalog_order',
				array(
					'default'    => 'DESC',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_catalog_order',
				array(
					'type'     		=> 'select',
					'choices'  		=> array( 
						'ASC' => __( 'Ascending', 'gomax' ),
						'DESC' => __( 'Descending', 'gomax' ),
					),
					'label'       => __( 'Order', 'gomax' ),
					'description' => __( 'Choose in which order the products will be displayed.', 'gomax' ),
					'settings'    => 'catalog_order',
					'section'     => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'catalog_image_display_mode',
				array(
					'default'    => 'single',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_catalog_image_display_mode',
				array(
					'type'     		=> 'select',
					'choices'  		=> array( 
						'single' => __( 'Single', 'gomax' ),
						'slides' => __( 'Slides', 'gomax' ),
						'change-on-hover' => 'Change on hover',
					),
					'label'       => __( 'Image Display Mode', 'gomax' ),
					'description' => __( 'The image display mode is the style in which the images of each product are shown.', 'gomax' ),
					'settings'    => 'catalog_image_display_mode',
					'section'     => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'catalog_add_button_pos',
				array(
					'default'    => '2',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_catalog_add_button_pos',
				array(
					'type'     		=> 'select',
					'choices'  		=> array( 
						'1' => __( 'After price', 'gomax' ),
						'2' => __( 'Overlay the image', 'gomax' ),
					),
					'label'       => __( 'Add Button Position', 'gomax' ),
					'description' => __( 'Select the positioning of the add to cart button.', 'gomax' ),
					'settings'    => 'catalog_add_button_pos',
					'section'     => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'show_result_count',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_result_count',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Result Count', 'gomax' ),
					'settings' => 'show_result_count',
					'section'  => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'show_layout_switcher',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_layout_switcher',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Layout Switcher', 'gomax' ),
					'settings' => 'show_layout_switcher',
					'section'  => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'show_sort_selector',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_sort_selector',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Sort Selector', 'gomax' ),
					'settings' => 'show_sort_selector',
					'section'  => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'show_sale_label',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_sale_label',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Sale Label', 'gomax' ),
					'settings' => 'show_sale_label',
					'section'  => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'show_wishlist',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_wishlist',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Wish List', 'gomax' ),
					'settings' => 'show_wishlist',
					'section'  => 'woocommerce_product_catalog',
					// Condition
					'active_callback' => function ( $control ) {
						return function_exists( 'woosw_init' );
					}
				)
			));

			$wp_customize->add_setting( 'show_compare',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_compare',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Compare', 'gomax' ),
					'settings' => 'show_compare',
					'section'  => 'woocommerce_product_catalog',
					// Condition
					'active_callback' => function ( $control ) {
						return function_exists( 'woosc_init' );
					}
				)
			));

			$wp_customize->add_setting( 'show_quick_view',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_quick_view',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Quick View', 'gomax' ),
					'settings' => 'show_quick_view',
					'section'  => 'woocommerce_product_catalog'
				)
			));

			$wp_customize->add_setting( 'show_description',
				array(
					'default'           => '',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field'
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_description',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Description', 'gomax' ),
					'settings' => 'show_description',
					'section'  => 'woocommerce_product_catalog'
				)
			));

			$wp_customize->add_setting( 'show_price',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field'
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_price',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Price', 'gomax' ),
					'settings' => 'show_price',
					'section'  => 'woocommerce_product_catalog'
				)
			));

			$wp_customize->add_setting( 'show_rating',
				array(
					'default'           => '',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_rating',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Rating', 'gomax' ),
					'settings' => 'show_rating',
					'section'  => 'woocommerce_product_catalog',
				)
			));

			$wp_customize->add_setting( 'show_categories',
				array(
					'default'           => '',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field'
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_categories',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Categories', 'gomax' ),
					'settings' => 'show_categories',
					'section'  => 'woocommerce_product_catalog'
				)
			));

			$wp_customize->add_setting( 'show_var_swatches',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field'
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_var_swatches',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Variation Swatches', 'gomax' ),
					'settings' => 'show_var_swatches',
					'section'  => 'woocommerce_product_catalog'
				)
			));

			#endregion Product Catalog 

			#region Product Summary

			$wp_customize->add_section( 'gomax_product_summary', 
				array(
					'title'       => __( 'Product Summary', 'gomax' ),
					'priority'    => 12,
					'capability'  => 'edit_theme_options',
					'description' => __( 'The options chosen here will apply to the product page and quick view. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
					'panel'				=> 'woocommerce',
				) 
			);

			$wp_customize->add_setting( 'product_thumbnail_direction',
				array(
					'default'    				=> 'vertical',
					'type'       				=> 'theme_mod',
					'capability' 				=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_thumbnail_direction',
				array(
					'type'     		 => 'select',
					'choices'  		 => array( 
						'vertical'   => __( 'Vertical', 'gomax' ),
						'horizontal' => __( 'Horizontal', 'gomax' ),
					),
					'label'       => __( 'Thumbnail direction', 'gomax' ),
					'description' => __( 'Choose orientation of product gallery thumbnails.', 'gomax' ),
					'settings'    => 'product_thumbnail_direction',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'show_product_sale_label',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_sale_label',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Sale Label', 'gomax' ),
					'settings' => 'show_product_sale_label',
					'section'  => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'show_product_wishlist',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_wishlist',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Wish List', 'gomax' ),
					'settings' => 'show_product_wishlist',
					'section'  => 'gomax_product_summary',
					// Condition
					'active_callback' => function ( $control ) {
						return function_exists( 'woosw_init' );
					}
				)
			));

			$wp_customize->add_setting( 'show_product_rating',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_rating',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Rating', 'gomax' ),
					'settings' => 'show_product_rating',
					'section'  => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'show_product_buy_now',
				array(
					'default'    => '1',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'transport'  => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_buy_now',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Buy Now', 'gomax' ),
					'settings' => 'show_product_buy_now',
					'section'  => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_buy_now_label',
				array(
					'default'    => __( 'Buy Now', 'gomax' ),
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'transport'  => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_buy_now_label',
				array(
					'type'        => 'text',
					'label'       => __( 'Buy Now Label', 'gomax' ),
					'settings'    => 'product_buy_now_label',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'show_product_share_this',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_share_this',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Share This', 'gomax' ),
					'settings' => 'show_product_share_this',
					'section'  => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_share_this_label',
				array(
					'default'           => __( 'Share This', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_share_this_label',
				array(
					'type'        => 'text',
					'label'       => __( 'Share This Label', 'gomax' ),
					'settings'    => 'product_share_this_label',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'show_product_compare',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_compare',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'Compare', 'gomax' ),
					'settings' => 'show_product_compare',
					'section'  => 'gomax_product_summary',
					// Condition
					'active_callback' => function ( $control ) {
						return function_exists( 'woosc_init' );
					}
				)
			));

			$wp_customize->add_setting( 'product_compare_label',
				array(
					'default'           => __( 'Compare', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_compare_label',
				array(
					'type'        => 'text',
					'label'       => __( 'Compare Label', 'gomax' ),
					'settings'    => 'product_compare_label',
					'section'     => 'gomax_product_summary',
					// Condition
					'active_callback' => function ( $control ) {
						return function_exists( 'woosc_init' );
					}
				)
			));

			$wp_customize->add_setting( 'show_product_more_info',
				array(
					'default'    => '1',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'transport'  => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_more_info',
				array(
					'type'     => 'checkbox',
					'label'    => __( 'More Info', 'gomax' ),
					'settings' => 'show_product_more_info',
					'section'  => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_more_info_label',
				array(
					'default'    => __( 'Product Details', 'gomax' ),
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'transport'  => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_more_info_label',
				array(
					'type'        => 'text',
					'label'       => __( 'More Info Label', 'gomax' ),
					'settings'    => 'product_more_info_label',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_more_info_link',
				array(
					'default'    => 'https://your-link',
					'type'       => 'theme_mod',
					'capability' => 'manage_woocommerce',
					'transport'  => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_more_info_link',
				array(
					'type'        => 'text',
					'label'       => __( 'More Info Link', 'gomax' ),
					'settings'    => 'product_more_info_link',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'show_product_meta',
				array(
					'default'           => '1',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_checkbox_field',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_show_product_meta',
				array(
					'type'        => 'checkbox',
					'label'       => __( 'Product Meta', 'gomax' ),
					'settings'    => 'show_product_meta',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_custom_image_title',
				array(
					'default'           => __( 'Image Title', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_custom_image_title',
				array(
					'type'        => 'text',
					'label'       => __( 'Custom Image Title', 'gomax' ),
					'settings'    => 'product_custom_image_title',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_custom_image_description',
				array(
					'default'           => __( 'Lorem ipsum dolor sit amet', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'transport'         => 'postMessage',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_custom_image_description',
				array(
					'type'        => 'text',
					'label'       => __( 'Custom Image Description', 'gomax' ),
					'settings'    => 'product_custom_image_description',
					'section'     => 'gomax_product_summary',
				)
			));

			$wp_customize->add_setting( 'product_custom_image',
				array(
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Image_Control (
				$wp_customize,
				'gomax_product_custom_image',
				array(
					'label'       => __( 'Custom Image', 'gomax' ),
					'description' => __( 'You can add a custom info image to the product details. This is useful for payment gateway banners.', 'gomax' ),
					'settings'    => 'product_custom_image',
					'section'     => 'gomax_product_summary',
				) 
			));

			#endregion Product Summary

			#region Product Tabs

			$wp_customize->add_section( 'gomax_product_tabs', 
				array(
					'title'       => __( 'Product Tabs', 'gomax' ),
					'priority'    => 13,
					'capability'  => 'edit_theme_options',
					'description' => __( 'The options chosen here will apply to the tabs on the product page. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
					'panel'				=> 'woocommerce',
				) 
			);

			$wp_customize->add_setting( 'product_tabs_mode',
				array(
					'default'           => 'custom',
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control(
				$wp_customize,
				'gomax_product_tabs_mode',
				array(
					'type'     => 'select',
					'choices'  => array( 
						'woocommerce' => __( 'WooCommerce Default', 'gomax' ),
						'custom' => __( 'Custom', 'gomax' ),
					),
					'label'    => __( 'Product Tabs Mode', 'gomax' ),
					'description' => __( 'The "Custom" option hides the WooCommerce default tabs, and allows you to customize it. You can edit each product with Elementor and create your own tab content.', 'gomax' ),
					'settings' => 'product_tabs_mode',
					'section'  => 'gomax_product_tabs',
				)
			));

			#endregion Product Tabs
		
			#region Product Images
 
			$wp_customize->add_setting( 'woocommerce_gallery_thumbnail_width', array(
				'default' => '140',
				'sanitize_callback' => 'absint',
			));
		
			$wp_customize->add_control( 'woocommerce_gallery_thumbnail_width_control', array(
				'label' => __( 'Gallery Thumbnail Width (px)', 'gomax' ),
				'section' => 'woocommerce_product_images',
				'settings' => 'woocommerce_gallery_thumbnail_width',
				'type' => 'number',
				'input_attrs' => array(
					'min' => 50,
					'max' => 300,
					'step' => 1,
				),
			));
		
			$wp_customize->add_setting( 'woocommerce_gallery_thumbnail_height', array(
				'default' => '175',
				'sanitize_callback' => 'absint',
			));
		
			$wp_customize->add_control( 'woocommerce_gallery_thumbnail_height_control', array(
				'label' => __( 'Gallery Thumbnail Height (px)', 'gomax'),
				'section' => 'woocommerce_product_images',
				'settings' => 'woocommerce_gallery_thumbnail_height',
				'type' => 'number',
				'input_attrs' => array(
					'min' => 50,
					'max' => 300,
					'step' => 1,
				),
			));

			#endregion Product Images

			#region Extended Features

			$wp_customize->add_section( 'gomax_woo_extended_features', 
				array(
					'title'       => __( 'Extended Features', 'gomax' ),
					'capability'  => 'edit_theme_options',
					'description' => __( 'Explore a variety of advanced options to enhance your WooCommerce store. ', 'gomax' ) . '<a href="'.esc_url( 'https://themeasy.co/help-center/gomax' ).'" class="external-link" target="_blank">'. __( 'Learn more', 'gomax' ) .'</a>',
					'panel'				=> 'woocommerce',
				) 
			);

			$wp_customize->add_setting( 'product_custom_field_location',
				array(
					'default'    				=> '',
					'type'       				=> 'theme_mod',
					'capability' 				=> 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);
			
			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_product_custom_field_location',
				array(
					'type'     		 => 'select',
					'choices' => array( 
						''        => __( 'Disabled', 'gomax' ),
						'all'     => __( 'Enable for All Products', 'gomax' ),
						'product' => __( 'Enable Per Product (Set Individually)', 'gomax' ),
					),
					'label'       => __( 'Product Custom Field', 'gomax' ),
					'description' => __( 'Allow customers to add custom text or details to their product order. Choose to enable this field for all products or configure it individually for each product.', 'gomax' ),
					'settings'    => 'product_custom_field_location',
					'section'     => 'gomax_woo_extended_features',
				)
			));

			$wp_customize->add_setting( 'product_custom_field_name',
				array(
					'default'           => __( 'Custom Name', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_product_custom_field_name',
				array(
					'type'        => 'text',
					'label'       => __( 'Field Name', 'gomax' ),
					'description' => __( 'The identifier displayed for this field in the shopping cart and order details.', 'gomax' ),
					'settings'    => 'product_custom_field_name',
					'section'     => 'gomax_woo_extended_features',
					// Condition
					'active_callback' => function ( $control ) {
						return $control->manager->get_setting( 'product_custom_field_location' )->value() !== '';
					}
				)
			));

			$wp_customize->add_setting( 'product_custom_field_label',
				array(
					'default'           => __( 'Add a custom name?', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_product_custom_field_label',
				array(
					'type'        => 'text',
					'label'       => __( 'Checkbox Label', 'gomax' ),
					'description' => __( 'The label shown next to the checkbox for adding a custom name to the product.', 'themeasy' ),
					'settings'    => 'product_custom_field_label',
					'section'     => 'gomax_woo_extended_features',
					// Condition
					'active_callback' => function ( $control ) {
						return $control->manager->get_setting( 'product_custom_field_location' )->value() !== '';
					}
				)
			));

			$wp_customize->add_setting( 'product_custom_field_description',
				array(
					'default'           => __( 'Use this field to add a custom name or text that you\'d like to appear on your product (e.g., for personalized shirts or other items).', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_product_custom_field_description',
				array(
					'type'        => 'textarea',
					'label'       => __( 'Field Description', 'gomax' ),
					'description' => __( 'A brief message displayed below the input field to explain its purpose, helping users understand how to add their custom text.', 'themeasy' ),
					'settings'    => 'product_custom_field_description',
					'section'     => 'gomax_woo_extended_features',
					// Condition
					'active_callback' => function ( $control ) {
						return $control->manager->get_setting( 'product_custom_field_location' )->value() !== '';
					}
				)
			));

			$wp_customize->add_setting( 'product_custom_field_placeholder',
				array(
					'default'           => __( 'Enter custom name here', 'gomax' ),
					'type'              => 'theme_mod',
					'capability'        => 'edit_theme_options',
					'sanitize_callback' => 'sanitize_data_value',
				)
			);

			$wp_customize->add_control( new WP_Customize_Control( $wp_customize, 'gomax_product_custom_field_placeholder',
				array(
					'type'        => 'text',
					'label'       => __( 'Input Placeholder', 'gomax' ),
					'description' => __( 'The hint text shown in the input field to guide users on what to type.', 'themeasy' ),
					'settings'    => 'product_custom_field_placeholder',
					'section'     => 'gomax_woo_extended_features',
					// Condition
					'active_callback' => function ( $control ) {
						return $control->manager->get_setting( 'product_custom_field_location' )->value() !== '';
					}
				)
			));

			#endregion Extended Features
		}
		
		/**
		 * Make sure that some data has been passed.
		 * 
		 * @package WordPress
		 * @since Gomax 1.0.0
		 */
		function sanitize_data_value( $data, $setting ) {		
			// If the input contains data, return it; otherwise, return the default.
			return $data ? $data : $setting->default;
		}

		/**
		 * Make sure that some data option has been passed.
		 * 
		 * @package WordPress
		 * @since Gomax 1.0.0
		 */
		function sanitize_checkbox_field( $data ) {
			// If data exist, return true; otherwise, return false.
			return isset( $data ) ? $data : false;
		}
	}

	/**
	 * This will output the custom WordPress settings to the live theme's WP head.
	 * 
   * @package WordPress
	 * @since Gomax 1.0.0
	 */
	public static function header_output() {
		?>
		<!-- Customizer CSS -->
		<style id="gomax-customizer-css">
			<?php
			#region Preloader

			self::generate_css( '.preloader', 'background-color', 'preloader_background_color' );
			self::generate_css( '.preloader .emblem', 'width', 'preloader_emblem_width', '', 'px' );

			#endregion Preloader

			#region Logo
			
			self::generate_css( '.header-section .navbar .navbar-brand .logo', 'height', 'logo_height', '', 'px' );

			#endregion Logo

			#region Color Scheme

			// Primary
			self::generate_css( ':root', '--themeasy-primary-color', 'primary_color' );
			self::generate_css( ':root', '--themeasy-primary-10-color', 'primary_color', '', '1a' );
			self::generate_css( ':root', '--themeasy-primary-15-color', 'primary_color', '', '26' );
			self::generate_css( ':root', '--themeasy-primary-25-color', 'primary_color', '', '40' );
			self::generate_css( ':root', '--themeasy-primary-50-color', 'primary_color', '', '80' );
			self::generate_css( ':root', '--themeasy-primary-75-color', 'primary_color', '', 'bf' );

			// Secondary
			self::generate_css( ':root', '--themeasy-secondary-color', 'secondary_color' );
			self::generate_css( ':root', '--themeasy-secondary-10-color', 'secondary_color', '', '1a' );
			self::generate_css( ':root', '--themeasy-secondary-15-color', 'secondary_color', '', '26' );
			self::generate_css( ':root', '--themeasy-secondary-25-color', 'secondary_color', '', '40' );
			self::generate_css( ':root', '--themeasy-secondary-50-color', 'secondary_color', '', '80' );
			self::generate_css( ':root', '--themeasy-secondary-75-color', 'secondary_color', '', 'bf' );

			// Auxiliary
			self::generate_css( ':root', '--themeasy-accent-color', 'accent_color' );
			self::generate_css( ':root', '--themeasy-info-color', 'info_color' );
			self::generate_css( ':root', '--themeasy-success-color', 'success_color' );
			self::generate_css( ':root', '--themeasy-danger-color', 'danger_color' );

			// Black & White
			self::generate_css( ':root', '--themeasy-black-color', 'black_color' );
			self::generate_css( ':root', '--themeasy-white-color', 'white_color' );

			// Background
			self::generate_css( ':root', '--themeasy-primary-bg-color', 'primary_bg_color' );
			self::generate_css( ':root', '--themeasy-secondary-bg-color', 'secondary_bg_color' );

			// Border
			self::generate_css( ':root', '--themeasy-primary-border-color', 'primary_border_color' );
			self::generate_css( ':root', '--themeasy-secondary-border-color', 'secondary_border_color' );

			// Text
			self::generate_css( ':root', '--themeasy-primary-text-color', 'primary_text_color' );
			self::generate_css( ':root', '--themeasy-secondary-text-color', 'secondary_text_color' );

			// Button
			self::generate_css( ':root', '--themeasy-primary-button-color', 'primary_button_color' );
			self::generate_css( ':root', '--themeasy-secondary-button-color', 'secondary_button_color' );

			#endregion Color Scheme

			#region Typography

			$font_mode = get_theme_mod( 'font_mode' );

			// Theme Defaults
			if ( $font_mode === 'theme-defaults' ) {

				$preset = get_theme_mod( 'font_family_preset' );

				// Preset 1
				if ( $preset == '1' ) {
					self::generate_css( 'body', '--themeasy-primary-font', '', '', '', 'Lato' );
					self::generate_css( 'body', '--themeasy-secondary-font', '', '', '', 'NeueHaas' );
				}
				// Preset 2
				if ( $preset == '2' ) {
					self::generate_css( 'body', '--themeasy-primary-font', '', '', '', 'Lato' );
					self::generate_css( 'body', '--themeasy-secondary-font', '', '', '', 'Circular' );
				}
				// Preset 3
				if ( $preset == '3' ) {
					self::generate_css( 'body', '--themeasy-primary-font', '', '', '', 'Roboto' );
					self::generate_css( 'body', '--themeasy-secondary-font', '', '', '', 'Larken' );
				}
			}

			// Google Fonts
			if ( $font_mode === 'google-fonts' ) {

				self::generate_css( 'body', '--themeasy-primary-font', 'google_primary_font' );
				self::generate_css( 'body', '--themeasy-secondary-font', 'google_secondary_font' );
		
				self::enqueue_fonts_css( 'google_primary_font' );
				self::enqueue_fonts_css( 'google_secondary_font' );
			}

			self::generate_css( 'h1', 'font-size', 'h1_font_size', '', 'rem' );
			self::generate_css( 'h1', 'font-weight', 'h1_font_weight' );

			self::generate_css( 'h2', 'font-size', 'h2_font_size', '', 'rem' );
			self::generate_css( 'h2', 'font-weight', 'h2_font_weight' );

			self::generate_css( 'h3', 'font-size', 'h3_font_size', '', 'rem' );
			self::generate_css( 'h3', 'font-weight', 'h3_font_weight' );

			self::generate_css( 'h4', 'font-size', 'h4_font_size', '', 'rem' );
			self::generate_css( 'h4', 'font-weight', 'h4_font_weight' );

			self::generate_css( 'h5', 'font-size', 'h5_font_size', '', 'rem' );
			self::generate_css( 'h5', 'font-weight', 'h5_font_weight' );

			self::generate_css( 'h6', 'font-size', 'h6_font_size', '', 'rem' );
			self::generate_css( 'h6', 'font-weight', 'h6_font_weight' );

			self::generate_css( 'body', '--themeasy-text-font-size', 'body_font_size', '', 'rem' );
			self::generate_css( 'body', '--themeasy-text-font-weight', 'body_font_weight' );

			#endregion Typography

			#region Layout

			self::generate_css( '@media (min-width:1200px) { .container', 'max-width', 'container_width_1200', '', 'px }' );
			self::generate_css( '@media (min-width:1300px) { .container', 'max-width', 'container_width_1300', '', 'px }' );
			self::generate_css( '@media (min-width:1400px) { .container', 'max-width', 'container_width_1400', '', 'px }' );
			self::generate_css( '@media (min-width:1500px) { .container', 'max-width', 'container_width_1500', '', 'px }' );
			self::generate_css( '@media (min-width:1600px) { .container', 'max-width', 'container_width_1600', '', 'px }' );
			self::generate_css( '@media (min-width:1700px) { .container', 'max-width', 'container_width_1700', '', 'px }' );
			self::generate_css( '@media (min-width:1800px) { .container', 'max-width', 'container_width_1800', '', 'px }' );

			#endregion Layout
			?>
		</style> 
		<!-- /Customizer CSS -->
		<?php
	}

	/**
	* This will generate a line of CSS for use in header output.
	* 
  * @package WordPress
	* @since Gomax 1.0.0
	*/
	public static function generate_css( $selector, $style, $value, $prefix = '', $postfix = '', $custom_value = '' ) {		
		$return = '';
		$value  = get_theme_mod( $value );
		
		if ( ! empty( $value ) ) {
			printf(
			'%s { %s:%s; }',
				$selector,
				$style,
				$prefix.$value.$postfix
			);
		}
		
		if ( ! empty( $custom_value ) ) {
			printf(
			'%s { %s:%s; }',
				$selector,
				$style,
				$prefix.$custom_value.$postfix
			);
		}
	}

	/**
	 * This will enable CSS from the selected font family.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	public static function enqueue_fonts_css( $value ) {
		$font_mode = get_theme_mod( 'font_mode' );
		$value     = get_theme_mod( $value );

		// Google Fonts
		if ( $font_mode === 'google-fonts' ) {

			$font_category = array(
				', serif', 
				', sans-serif',
				', display',
				', handwriting',
				', monospace'
			);
	
			$font = str_replace( $font_category, '', $value );

			$url = add_query_arg( 
				'family', 
				urlencode( $font . ':100,200,300,400,500,600,700,800,900&display=swap' ), 
				'//fonts.googleapis.com/css' 
			);

			wp_enqueue_style( sanitize_title( 'gomax-font-family-' . $font ), $url, array(), gomax_get_theme_version() );
		}
	}
	
	/**
	 * Add the necessary assets to automate the live preview.
	 * 
   * @package WordPress
	 * @since Gomax 1.0.0
	 */
	public static function live_preview() {
		// Enqueue customizer live preview script.
		wp_enqueue_script( 'gomax-customizer', get_template_directory_uri() . '/assets/js/admin/customizer.min.js', array( 'jquery', 'customize-preview' ), gomax_get_theme_version(), true );
	}
	
	/**
	 * Add the necessary assets to automate the live preview controls.
	 * 
   * @package WordPress
	 * @since Gomax 1.0.0
	 */
	public static function live_preview_controls() {

		// Enqueue customizer control styles.
		wp_enqueue_style( 'gomax-customizer', get_template_directory_uri() . '/assets/css/admin/customizer.min.css', array(), gomax_get_theme_version());

		// WooCommerce controls are only added if the Themeasy plugin is active.
		if ( gomax_has_core() && gomax_has_woocommerce() ) {

			// Consult the registered products to get the link of the first item.
			$args = array(
				'limit'   => 1,
				'status'  => 'publish',
				'orderby' => 'date',
				'order'   => 'DESC'
			);
			
			// Perform query
			$query = new WC_Product_Query($args);

			// Collect product object
			$products = $query->get_products();

			// Avoid when there are no results
			$first_product_link = '';

			// Loop through products
			if ( ! empty( $products ) ) {
				foreach ($products as $product) {
					$first_product_link = get_permalink( $product->get_id() );
					break;
				}
			}
		}
		?>
		<!-- Typography -->
		<script>
			jQuery(function ($) {
				'use strict';

				// Font Mode
				wp.customize('font_mode', function (value) {
					value.bind(function (newval) {

						// Show or hide fields conditionally
						if (newval === 'theme-defaults') {
							
							// Activate
							wp.customize.control('gomax_font_family_preset').activate();

							// Deactivate
							wp.customize.control('gomax_google_primary_font').deactivate();
							wp.customize.control('gomax_google_secondary_font').deactivate();
						}
						else if (newval === 'google-fonts') {

							// Deactivate
							wp.customize.control('gomax_font_family_preset').deactivate();

							// Activate
							wp.customize.control('gomax_google_primary_font').activate();
							wp.customize.control('gomax_google_secondary_font').activate();
						}
					})
				})

				var font_mode_selector = wp.customize.control('gomax_font_mode').selector;
				
				$('body').on('change', font_mode_selector, function() {

					if ( $(this).find(':selected').val() === 'theme-defaults' ) {
						
						// Font Family Preset
						var preset_selector       = $(wp.customize.control('gomax_font_family_preset').selector).find('select');
						var preset_selector_value = preset_selector.val();

						// Reset
						if ( preset_selector_value == '1' ) {
							preset_selector.val('2');
						} else {
							preset_selector.val('1');
						}
						preset_selector.trigger('change');
						preset_selector.val(preset_selector_value);
						preset_selector.trigger('change');
					}

					if ( $(this).find(':selected').val() === 'google-fonts' ) {

						// Primary Font
						var primary_font_selector = $(wp.customize.control('gomax_google_primary_font').selector).find('select');
						var primary_font_value = primary_font_selector.val();

						// Reset
						if ( primary_font_value === 'Lato, sans-serif' ) {
							primary_font_selector.val('Roboto, sans-serif');
						} else {
							primary_font_selector.val('Lato, sans-serif');
						}
						primary_font_selector.trigger('change');
						primary_font_selector.val(primary_font_value);
						primary_font_selector.trigger('change');

						// Secondary Font
						var secondary_font_selector = $(wp.customize.control('gomax_google_secondary_font').selector).find('select');
						var secondary_font_value = secondary_font_selector.val();

						// Reset
						if ( secondary_font_value === 'Lato, sans-serif' ) {
							secondary_font_selector.val('Roboto, sans-serif');
						} else {
							secondary_font_selector.val('Lato, sans-serif');
						}
						secondary_font_selector.trigger('change');
						secondary_font_selector.val(secondary_font_value);
						secondary_font_selector.trigger('change');
					}
				})
			})
		</script>
		<?php
		// WooCommerce controls are only added if the Themeasy plugin is active.
		if ( gomax_has_core() && gomax_has_woocommerce() ) {
			?>
			<!-- WooCommerce -->
			<script>
				jQuery(function ($) {
					'use strict';

					// Product Catalog
					wp.customize.section( 'woocommerce_product_catalog', function(section) {
						section.expanded.bind(function(isExpanded) {
							if (isExpanded) {
								wp.customize.previewer.previewUrl.set( '<?php echo esc_js( wc_get_page_permalink( 'shop' ) ); ?>' );
							}
						})
					})

					// Product Summary
					wp.customize.section( 'gomax_product_summary', function(section) {
						section.expanded.bind(function(isExpanded) {
							if (isExpanded) {
								wp.customize.previewer.previewUrl.set( '<?php echo esc_js( $first_product_link ); ?>' );
							}
						})
					})

					// Product Tabs
					wp.customize.section( 'gomax_product_tabs', function(section) {
						section.expanded.bind(function(isExpanded) {
							if (isExpanded) {
								wp.customize.previewer.previewUrl.set( '<?php echo esc_js( $first_product_link ); ?>#product-tabs' );
							}
						})
					})

					// Extended Features
					wp.customize.section( 'gomax_woo_extended_features', function(section) {
						section.expanded.bind(function(isExpanded) {
							if (isExpanded) {
								wp.customize.previewer.previewUrl.set( '<?php echo esc_js( $first_product_link ); ?>' );
							}
						})
					})
				})
			</script>
			<?php
		}
	}
}

/**
 * Setup the Theme Customizer settings and controls.
 * 
 * @package Gomax
 * @since 1.0.0
 */
add_action( 'customize_register', array( 'Gomax_Customize', 'register' ) );

/**
 * Output custom CSS to live site.
 * 
 * @package Gomax
 * @since 1.0.0
 */
add_action( 'wp_head', array( 'Gomax_Customize', 'header_output' ) );

/**
 * Enqueue live preview assets in Theme Customizer admin screen.
 * 
 * @package Gomax
 * @since 1.0.0
 */
add_action( 'customize_preview_init', array( 'Gomax_Customize', 'live_preview' ) );

/**
 * Enqueue live preview controls assets in Theme Customizer admin screen.
 * 
 * @package Gomax
 * @since 1.0.0
 */
add_action( 'customize_controls_print_scripts', array( 'Gomax_Customize', 'live_preview_controls' ) );