<?php
/**
 * Adds compatibility with JetPack plugin features.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

function gomax_jetpack_setup() { 

	/**
	 * Infinite scroll support.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	add_theme_support(
		'infinite-scroll',
		array(
			'container' => 'main',
			'render'    => 'gomax_infinite_scroll_render',
			'footer'    => 'page',
		)
	);

	/**
	 * Responsive videos support.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	add_theme_support( 'jetpack-responsive-videos' );

	/**
	 * JetPack options support.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	add_theme_support(
		'jetpack-content-options',
		array(
			'post-details' => array(
				'stylesheet' => 'gomax-jetpack-style',
				'date'       => '.posted-on',
				'categories' => '.cat-links',
				'tags'       => '.tags-links',
				'author'     => '.byline',
				'comment'    => '.comments-link',
			),
			'featured-images' => array(
				'archive' => true,
				'post'    => true,
				'page'    => true,
			),
		)
	);
}
add_action( 'after_setup_theme', 'gomax_jetpack_setup' );

/**
 * Renders the theme post template.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_infinite_scroll_render() {
	while ( have_posts() ) {
		the_post();
		get_template_part( 'template-parts/post' );
	}
}