<?php
/**
 * Import the pre-built content of the theme.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

// Check the parameter 'e-websites' on the page
function demo_type_e_websites() {
	return isset( $_GET['demo_type'] ) && $_GET['demo_type'] === 'e-websites';
}

// Check the parameter 'c-websites' on the page
function demo_type_c_websites() {
	return isset( $_GET['demo_type'] ) && $_GET['demo_type'] === 'c-websites';
}

/**
 * Add import type class to body.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_ocdi_body_class( $classes ) {
	if ( demo_type_e_websites() ) {
		$classes .= ' gomax-import-type-e-websites';
	}
	if ( demo_type_c_websites() ) {
		$classes .= ' gomax-import-type-c-websites';
	}
	return $classes;
}
add_filter( 'admin_body_class', 'gomax_ocdi_body_class', 10, 1 );

/**
 * Display intro page before import.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_ocdi_intro_content( $content ) {
	ob_start();
	if ( demo_type_e_websites() || demo_type_c_websites() ) {
		?>
		<a href="<?php echo admin_url( '/themes.php?page=one-click-demo-import' ); ?>" class="ocdi__go-back-icon" hidden>
			<span class="gomax-icon dashicons dashicons-arrow-left-alt"></span>
		</a>
	<?php
	} else {
		?>
		<div class="gomax-import-options gomax-row">
			<!-- Pre-Built Website [Essential] -->
			<div class="gomax-col">
				<div class="gomax-box">
					<div class="title">
						<?php echo __( 'Pre-Built Website', 'gomax' ); ?>
						<span class="gomax-badge no-icon valid"><?php echo __( 'Essential Package', 'gomax' ); ?></span>
					</div>
					<div class="inner">
						<?php 
						printf(
							/* translators: %1$s and %2$s - <em> HTML tags */
							'<p>' . __( 'Import all demos, %1$sexcept WooCommerce content%2$s. The homepage and site menus will be configured based on the selected demo\'s homepage.', 'gomax' ) . '</p>',
							'<em>', '</em>'
						); ?>
						<ul class="checklist">
							<li class="yes"><?php echo esc_html( 'Pages and Posts', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Global Sections', 'gomax' ); ?><span><?php echo esc_html( '(header, footer and more)', 'gomax' ); ?></span></li>
							<li class="yes"><?php echo esc_html( 'Media Files', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Menus', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Megamenus', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Contact Forms', 'gomax' ); ?></li>
							<li class="no"><?php echo esc_html( 'Products', 'gomax' ); ?></li>
							<li class="no"><?php echo esc_html( 'Shop Styles', 'gomax' ); ?></li>
							<li class="no"><?php echo esc_html( 'Element Pages', 'gomax' ); ?></li>
						</ul>
						<a href="<?php echo admin_url( '/themes.php?page=one-click-demo-import&demo_type=e-websites' ); ?>" class="gomax-button button button-primary">
							<?php echo esc_html( 'Import Website', 'gomax' ); ?>
						</a>
					</div>
				</div>
			</div>
			<!-- Pre-Built Website [Complete] -->
			<div class="gomax-col">
				<div class="gomax-box">
					<div class="title">
						<?php echo __( 'Pre-Built Website', 'gomax' ); ?>
						<span class="gomax-badge no-icon valid"><?php echo __( 'Complete Package', 'gomax' ); ?></span>
					</div>
					<div class="inner">
						<?php 
						printf(
							/* translators: %1$s and %2$s - <em> HTML tags */
							'<p>' . __( 'Import all demos, %1$sexcept WooCommerce content%2$s. The homepage and site menus will be configured based on the selected demo\'s homepage.', 'gomax' ) . '</p>',
							'<em>', '</em>'
						); ?>
						<ul class="checklist">
							<li class="yes"><?php echo esc_html( 'Pages and Posts', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Global Sections', 'gomax' ); ?><span><?php echo esc_html( '(header, footer and more)', 'gomax' ); ?></span></li>
							<li class="yes"><?php echo esc_html( 'Media Files', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Menus', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Megamenus', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Contact Forms', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Products', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Shop Styles', 'gomax' ); ?></li>
							<li class="yes"><?php echo esc_html( 'Element Pages', 'gomax' ); ?></li>
						</ul>
						<a href="<?php echo admin_url( '/themes.php?page=one-click-demo-import&demo_type=c-websites' ); ?>" class="gomax-button button button-primary">
							<?php echo esc_html( 'Import Website', 'gomax' ); ?>
						</a>
					</div>
				</div>
			</div>
			<!-- WooCommerce Products -->
			<div class="gomax-col">
				<div class="gomax-box">
					<div class="title">
						<?php echo __( 'WooCommerce Products', 'gomax' ); ?>
					</div>
					<div class="inner">
						<?php 
						printf(
							/* translators: %1$s and %2$s - <em> HTML tags */
							'<p>' . __( 'Import all demo products. This can be useful as a base to start from.', 'gomax' ) . '</p>',
							'<em>', '</em>'
						); ?>
						<a href="<?php echo admin_url( '/themes.php?page=one-click-demo-import&step=import&import=0&demo_type=products' ); ?>" class="gomax-button button button-primary">
							<?php echo esc_html( 'Import Products', 'gomax' ); ?>
						</a>
					</div>
				</div>
			</div>
			<!-- Shop Styles -->
			<div class="gomax-col">
				<div class="gomax-box">
					<div class="title">
						<?php echo __( 'Shop Styles', 'gomax' ); ?>
					</div>
					<div class="inner">
						<?php 
						printf(
							/* translators: %1$s and %2$s - <em> HTML tags */
							'<p>' . __( 'Import all demo shop pages, then select your preferred one as the default WooCommerce catalog page.', 'gomax' ) . '</p>',
							'<em>', '</em>'
						); ?>
						<a href="<?php echo admin_url( '/themes.php?page=one-click-demo-import&step=import&import=1&demo_type=shop' ); ?>" class="gomax-button button button-primary">
							<?php echo esc_html( 'Import Shop Styles', 'gomax' ); ?>
						</a>
					</div>
				</div>
			</div>
			<!-- Element Pages -->
			<div class="gomax-col">
				<div class="gomax-box">
					<div class="title">
						<?php echo __( 'Element Pages', 'gomax' ); ?>
					</div>
					<div class="inner">
						<?php 
						printf(
							/* translators: %1$s and %2$s - <em> HTML tags */
							'<p>' . __( 'Import all the element pages you see in the demo. This can be useful for building your own pages.', 'gomax' ) . '</p>',
							'<em>', '</em>'
						); ?>
						<a href="<?php echo admin_url( '/themes.php?page=one-click-demo-import&step=import&import=2&demo_type=elements' ); ?>" class="gomax-button button button-primary">
							<?php echo esc_html( 'Import Element Pages', 'gomax' ); ?>
						</a>
					</div>
				</div>
			</div>
			<!-- Templates -->
			<div class="gomax-col">
				<div class="gomax-box">
					<div class="title">
						<?php echo __( 'Templates', 'gomax' ); ?>
						<span class="gomax-badge no-icon info"><?php echo __( 'Coming Soon', 'gomax' ); ?></span>
					</div>
					<div class="inner">
						<?php 
						printf(
							/* translators: %1$s and %2$s - <em> HTML tags */
							'<p>' . __( 'We\'re crafting a stunning collection of templates that will soon be available in a future update.', 'gomax' ) . '</p>',
							'<em>', '</em>'
						); ?>
						<a href="#" class="gomax-button button button-primary" disabled>
							<?php echo esc_html( 'Import Templates', 'gomax' ); ?>
						</a>
					</div>
				</div>
			</div>
		</div>
	<?php
	}
	$content = ob_get_clean();
	return $content;
}
add_filter( 'ocdi/plugin_intro_text', 'gomax_ocdi_intro_content' );

/**
 * Defines where the import data will come from.
 * 
 * @package Gomax
 * @since 1.0.0 
 */
function gomax_ocdi_import_demos() {

	// Prepare list
	function gomax_import_demos_list( $demo_type, $categories, $demo_category, $file_path, $file_name, $preview_url ) {

		$file_url  = 'https://package.themeasy.co/demo-data/gomax/105-39CC75B591775/' . $file_path . '/' . $file_name . '.xml';
		$image_url = '';

		if ( $demo_type === 'e-websites' || $demo_type === 'c-websites' ) {
			$image_url = get_template_directory_uri() . '/assets/images/demos/' . $demo_category . '/' . $file_name . '.jpg';
		}	

		return array(
			'categories'               => array( $categories ),
			'import_file_name'         => str_replace( '-', ' ', $file_name ),
			'import_file_url'          => $file_url,
			'import_preview_image_url' => $image_url,
			'preview_url'              => $preview_url
		);
	}

	return array(

		// All Products
		array(
			'import_file_name' => __( 'All Products', 'gomax' ),
			'categories'       => array( 'direct' ),
			'import_file_url'  => 'https://package.themeasy.co/demo-data/gomax/105-39CC75B591775/Products.xml',
			'preview_url'      => 'https://gomax.themeasy.co/shop/'
		),
		// All Shop Styles
		array(
			'import_file_name' => __( 'All Shop Styles', 'gomax' ),
			'categories'       => array( 'direct' ),
			'import_file_url'  => 'https://package.themeasy.co/demo-data/gomax/105-39CC75B591775/Shop-Styles.xml',
			'preview_url'      => 'https://gomax.themeasy.co/shop/'
		),
		// All Element Pages
		array(
			'import_file_name' => __( 'All Element Pages', 'gomax' ),
			'categories'       => array( 'direct' ),
			'import_file_url'  => 'https://package.themeasy.co/demo-data/gomax/105-39CC75B591775/Element-Pages.xml',
			'preview_url'      => 'https://gomax.themeasy.co'
		),

		// Essential Websites
		gomax_import_demos_list( 'e-websites', 'Essential Website: Fashion', 'fashion', 'essential-websites/fashion', 'Website-1', 'https://gomax.themeasy.co/home-1/' ),
		gomax_import_demos_list( 'e-websites', 'Essential Website: Fashion', 'fashion', 'essential-websites/fashion', 'Website-2', 'https://gomax.themeasy.co/home-2/' ),
		gomax_import_demos_list( 'e-websites', 'Essential Website: Fashion', 'fashion', 'essential-websites/fashion', 'Website-3', 'https://gomax.themeasy.co/home-3/' ),
		gomax_import_demos_list( 'e-websites', 'Essential Website: Fashion', 'fashion', 'essential-websites/fashion', 'Website-4', 'https://gomax.themeasy.co/home-4/' ),
		gomax_import_demos_list( 'e-websites', 'Essential Website: Fashion', 'fashion', 'essential-websites/fashion', 'Website-5', 'https://gomax.themeasy.co/home-5/' ),
		gomax_import_demos_list( 'e-websites', 'Essential Website: Fashion', 'fashion', 'essential-websites/fashion', 'Website-6', 'https://gomax.themeasy.co/home-6/' ),		
		gomax_import_demos_list( 'e-websites', 'Essential Website: Furniture', 'furniture', 'essential-websites/furniture', 'Website-1', 'https://gomax-furniture.themeasy.co/home-1/' ),
		gomax_import_demos_list( 'e-websites', 'Essential Website: Furniture', 'furniture', 'essential-websites/furniture', 'Website-2', 'https://gomax-furniture.themeasy.co/home-2/' ),

		// Complete Websites
		gomax_import_demos_list( 'c-websites', 'Complete Website: Fashion', 'fashion', 'complete-websites/fashion', 'Website-1', 'https://gomax.themeasy.co/home-1/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Fashion', 'fashion', 'complete-websites/fashion', 'Website-2', 'https://gomax.themeasy.co/home-2/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Fashion', 'fashion', 'complete-websites/fashion', 'Website-3', 'https://gomax.themeasy.co/home-3/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Fashion', 'fashion', 'complete-websites/fashion', 'Website-4', 'https://gomax.themeasy.co/home-4/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Fashion', 'fashion', 'complete-websites/fashion', 'Website-5', 'https://gomax.themeasy.co/home-5/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Fashion', 'fashion', 'complete-websites/fashion', 'Website-6', 'https://gomax.themeasy.co/home-6/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Furniture', 'furniture', 'complete-websites/furniture', 'Website-1', 'https://gomax-furniture.themeasy.co/home-1/' ),
		gomax_import_demos_list( 'c-websites', 'Complete Website: Furniture', 'furniture', 'complete-websites/furniture', 'Website-2', 'https://gomax-furniture.themeasy.co/home-2/' ),

	);
}
add_filter( 'ocdi/import_files', 'gomax_ocdi_import_demos' );

/**
 * Execute functions after import.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_ocdi_after_import( $selected ) {

	// Set Home Page
	$import_file_name = str_replace( '-', ' ', $selected['import_file_name'] );
	$page_title       = str_replace( 'Website', 'Home', $import_file_name );

	if ( strpos( $import_file_name, 'Website' ) !== false ) {
		$home_page = new WP_Query( [
			'post_type'   => 'page',
			'title'       => $page_title,
			'post_status' => 'publish',
		] );

		if ( $home_page->have_posts() ) {
			$home_page->the_post(); // Set the first post from the query
			update_option( 'page_on_front', get_the_ID() );
			update_option( 'show_on_front', 'page' );
			wp_reset_postdata(); // Clean up after WP_Query
		}
	}

	// Set WooCommerce pages
	if ( class_exists( 'WooCommerce' ) ) {
		$pages_to_set = [
			'woocommerce_cart_page_id'     => 'Shopping Cart',
			'woocommerce_checkout_page_id' => 'Checkout',
			'woocommerce_shop_page_id'     => 'Shop',
		];
	
		foreach ( $pages_to_set as $option_name => $page_title ) {
			$page_query = new WP_Query( [
				'post_type'   => 'page',
				'title'       => $page_title,
				'post_status' => 'publish',
			] );
	
			if ( $page_query->have_posts() ) {
				$page_query->the_post(); // Set the first post from the query
				update_option( $option_name, get_the_ID() );
				wp_reset_postdata(); // Clean up after WP_Query
			}
		}
	}

	// Set Menu
	function gomax_set_menu( $menu_name, $menu_location ) {
		$menu = get_term_by( 'name', $menu_name, 'nav_menu' );
		$location = get_theme_mod( 'nav_menu_locations' );
		$location[$menu_location] = $menu->term_id;
		set_theme_mod( 'nav_menu_locations', $location );
	}
	gomax_set_menu( 'Gomax Menu 1', 'menu-1' );
	gomax_set_menu( 'Gomax Menu 2', 'menu-2' );
	gomax_set_menu( 'Gomax Menu 3', 'menu-3' );
	gomax_set_menu( 'Gomax Menu 4', 'menu-4' );
	gomax_set_menu( 'Gomax Language Switcher', 'menu-5' );
	gomax_set_menu( 'Gomax Currency Switcher', 'menu-6' );

	// Theme Settings
	update_option( 'woocommerce_single_image_width', 640 );
	update_option( 'woocommerce_thumbnail_image_width', 300 );
	update_option( 'woocommerce_thumbnail_cropping', 'custom' );
	update_option( 'woocommerce_thumbnail_cropping_custom_width', 4 );
	update_option( 'woocommerce_thumbnail_cropping_custom_height', 5 );

	/**
	 * Updates the attribute type of a WooCommerce product attribute.
	 * This function retrieves the WooCommerce attribute taxonomies stored 
	 * in the '_transient_wc_attribute_taxonomies' option, finds the specified 
	 * attribute by name, and updates its attribute type.
	 * 
	 * @package Gomax
	 * @since 1.0.2
	 */
	function gomax_update_wc_attribute_type( $attribute_name, $new_type ) {
		global $wpdb;

		// Check if WooCommerce is active
		if ( ! class_exists( 'WooCommerce' ) ) {
			return; // Exit if WooCommerce is not active
		}

		// 1. Update in _transient_wc_attribute_taxonomies (wp_options)
		$attribute_taxonomies = get_option( '_transient_wc_attribute_taxonomies' );

		if ( ! empty( $attribute_taxonomies ) && is_array( $attribute_taxonomies ) ) {
			foreach ( $attribute_taxonomies as &$attribute ) {
				if ( $attribute->attribute_name === $attribute_name ) {
					// Change the attribute type in the transient data
					$attribute->attribute_type = $new_type;
					break;
				}
			}
			// Update the transient with new values
			set_transient( 'wc_attribute_taxonomies', $attribute_taxonomies );
			update_option( '_transient_wc_attribute_taxonomies', $attribute_taxonomies );
		}

		// 2. Update the wp_woocommerce_attribute_taxonomies table
		$table_name = $wpdb->prefix . 'woocommerce_attribute_taxonomies';
		$wpdb->update(
			$table_name,
			array( 'attribute_type' => $new_type ), // New value
			array( 'attribute_name' => str_replace( 'pa_', '', $attribute_name ) ) // Condition (remove 'pa_' prefix for table compatibility)
		);
	}

	// Update imported theme attributes
	gomax_update_wc_attribute_type( 'brand', 'label' );
	gomax_update_wc_attribute_type( 'number', 'label' );
	gomax_update_wc_attribute_type( 'size', 'label' );
	gomax_update_wc_attribute_type( 'color', 'color' );
	gomax_update_wc_attribute_type( 'pattern', 'image' );

	/**
	 * Third-party plugin configuration.
	 * 
	 * @package Gomax
	 * @since 1.0.2
	 */
	// Changes the Elementor settings.
	$elementor_experiment_font_svg = get_option( 'elementor_experiment-e_font_icon_svg' );
	if ( $elementor_experiment_font_svg === false ) {
    add_option( 'elementor_experiment-e_font_icon_svg', 'inactive' );
	} else {
    update_option( 'elementor_experiment-e_font_icon_svg', 'inactive' );
	}

	// Changes the FiboSearch settings.
	$dgwt_wcas_settings = get_option( 'dgwt_wcas_settings' );
	if ( ! empty( $dgwt_wcas_settings ) && is_array( $dgwt_wcas_settings ) ) {
		$dgwt_wcas_settings['max_form_width'] = '0';
		$dgwt_wcas_settings['search_style'] = 'solaris';
		$dgwt_wcas_settings['show_submit_button'] = 'on';
		$dgwt_wcas_settings['search_submit_text'] = '';
		$dgwt_wcas_settings['enable_mobile_overlay'] = 'off';
		$dgwt_wcas_settings['show_product_price'] = 'on';
		$dgwt_wcas_settings['show_product_tax_product_tag'] = 'on';
		update_option( 'dgwt_wcas_settings', $dgwt_wcas_settings );
	}

	// Retrieve WPC Product Size Chart existing settings
	$current_settings = (array) get_option( 'wpcsc_settings', [] );

	// Update the values
	$current_settings['library'] = 'magnific';
	$current_settings['effect'] = 'mfp-fade';

	// Save the updated settings silently
	update_option( 'wpcsc_settings', $current_settings );
}
add_action( 'ocdi/after_import', 'gomax_ocdi_after_import' );

/**
 * Display recommended plugins.
 * 
 * @package Gomax
 * @since 1.0.0
 */
function gomax_ocdi_register_plugins( $plugins ) {
  $theme_plugins = [
    [
      'name'        => 'Themeasy',
      'slug'        => 'themeasy',
      'description' => __( 'The main plugin responsible for all the functionality of the Gomax Theme.', 'gomax' ),
      'source'      => esc_url( 'https://package.themeasy.co/plugins/themeasy-v1.0.4.zip' ),
      'required'    => true,
    ],
		[
			'name'        => 'Elementor',
			'slug'        => 'elementor',
      'description' => __( 'World\'s best drag and drop page builder to customize websites.', 'gomax' ),
      'preselected' => true,
		],
		[
			'name'        => 'Contact Form 7',
			'slug'        => 'contact-form-7',
      'description' => __( 'Just another contact form plugin. Simple but flexible.', 'gomax' ),
      'preselected' => true,
		],
  ];

  return array_merge( $plugins, $theme_plugins );
}
add_filter( 'ocdi/register_plugins', 'gomax_ocdi_register_plugins' );

/**
 * Disable thumbnail image generation.
 * 
 * @package Gomax
 * @since 1.0.0
 */
add_filter( 'ocdi/regenerate_thumbnails_in_content_import', '__return_false' );