<?php
/**
 * This template is displayed when a page is archive.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

/**
 * Check the page template type and pass the arguments.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( is_page_template( 'templates/portfolio-list.php' ) ) {
	$is_portfolio = true;
	$is_blog      = false;
	$sidebar      = 'portfolio-sidebar';
	
	$args = array(
		'post_type'      => 'portfolio',
		'post_status'    => 'publish',
		'order'          => 'DESC',
		'paged'          => ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1
	);

	query_posts( $args );
	
} elseif ( is_page_template( 'templates/blog-list.php' ) ) {
	$is_blog      = true;
	$is_portfolio = false;
	$sidebar      = 'post-sidebar';
	
	$args = array(
		'post_type'      => 'post',
		'post_status'    => 'publish',
		'order'          => 'DESC',
		'paged'          => ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1
	);

	query_posts( $args );

} else {	
	$is_portfolio = false;
	$sidebar      = 'post-sidebar';
}

/**
 * Set the columns.
 * 
 * @package Gomax
 * @since 1.0.0
 */
$columns = get_theme_mod( 'blog_columns', '1' );

/**
 * Set the classes.
 * 
 * @package Gomax
 * @since 1.0.0
 */
$container_class_attr         = 'container';
$archive_container_class_attr = 'container';
$row_class_attr               = 'row g-0';
$col_class_attr               = 'col-12';

if ( gomax_has_sidebar( $sidebar ) ) {
	$container_class_attr         .= ' full-container';
	$archive_container_class_attr .= ' full-container';
	$row_class_attr               .= 'row g-5';
	$col_class_attr               .= ' col-md-8';

} else {
	if ( $columns >= 3 ) {
		$container_class_attr         .= ' full-container';
		$archive_container_class_attr .= ' full-container';
	}
}

// Check the title of the page and according to the type
$page_title = gomax_get_page_title();
?>
<main id="main" class="main-section">
	<?php if ( $page_title ) : ?>
		<section class="intro-section pt-5">
			<div class="<?php echo esc_attr( $container_class_attr ); ?>">
				<div class="container-inner">
					<div class="post-intro-title">
						<?php
						// Post Title
						if ( $page_title ) :
							printf(
								'<h1 class="title entry-title">%s</h1>',
								$page_title
							);
						endif;
						?>
					</div>					
				</div>
			</div>
		</section>
	<?php endif; ?>
	<!-- Archive -->
	<section id="post-<?php the_ID(); ?>" <?php post_class( 'archive-section pt-5 pb-5' ); ?>>
		<div class="<?php echo esc_attr( $archive_container_class_attr ) ?>">
			<div class="container-inner">
				<div class="<?php echo esc_attr( $row_class_attr ) ?>">
					<div class="<?php echo esc_attr( $col_class_attr ) ?>">
						<div class="archive-page">
							<?php gomax_get_breadcrumb(); ?>
							<div class="post-grid bricklayer" data-columns="<?php echo esc_attr( $columns ); ?>">
								<?php
								if ( have_posts() ) {

									while ( have_posts() ) {
										the_post();
										get_template_part( 'template-parts/post' );
									}
									wp_reset_postdata();

								} else {

									if ( is_archive() ) {
										/* translators: %1$s - text, %2$s - link, %3$s - label */
										printf(
											'<p>%1$s <a href="%2$s" rel="nofollow">%3$s</a></p>',
											esc_html__( 'There is still no content available for this term.', 'gomax' ),
											esc_url( home_url( '/' ) ),
											esc_html__( 'Back to home page', 'gomax' )
										);

									} else {								
										$post_new_url = '/post-new.php';
										if ( $is_portfolio ) {
											$post_new_url .= '?post_type=portfolio';
										}
										/* translators: %1$s - text, %2$s - link, %3$s - label */
										printf(
											'<p>%1$s <a href="%2$s" rel="nofollow">%3$s</a></p>',
											esc_html__( 'Ready to publish your first post?', 'gomax' ),
											esc_url( admin_url( $post_new_url ) ),
											esc_html__( 'Get started', 'gomax' )
										);
									}
								}
								?>
							</div>
							<?php					
							// Pagination 
							$pagination_args = array(
								'current'   => max( 1, get_query_var( 'paged' ) ),
								'end_size'  => 1,
								'mid_size'  => 2,
								'prev_text' => '<i class="fa-solid fa-arrow-left-long icon"></i>',
								'next_text' => '<i class="fa-solid fa-arrow-right-long icon"></i>',
								'type'      => 'list'
							);

							if ( get_the_posts_pagination( $pagination_args ) ) {
								the_posts_pagination( $pagination_args );
							}
							?>
						</div>
					</div>
					<?php gomax_get_sidebar( $sidebar ); ?>
				</div>
			</div>
		</div>
	</section>	
</main>