<?php
/**
 * This is the main header template.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.
?>
<header id="header" class="header-section">
  <nav id="navbar" class="navbar navbar-expand-lg">
    <div class="container">
      <a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="navbar-brand">
        <?php
        if ( has_custom_logo() ) :
          // Get the registered logo image
          $custom_logo = get_theme_mod( 'custom_logo' );
          $custom_logo = wp_get_attachment_image_src( $custom_logo , 'full' );
          $custom_logo = $custom_logo[0];          
          $sticky_logo = get_theme_mod( 'sticky_logo' );
          $mobile_logo = get_theme_mod( 'mobile_logo' );

          // If there is no image, take the default logo
          $sticky_logo = ( ! $sticky_logo ? $custom_logo : $sticky_logo );
          $mobile_logo = ( ! $mobile_logo ? $custom_logo : $mobile_logo );
          ?>
          <img src="<?php echo esc_url( $custom_logo ); ?>" alt="<?php bloginfo( 'name' ); ?>" class="logo main-logo" />
          <img src="<?php echo esc_url( $sticky_logo ); ?>" alt="<?php bloginfo( 'name' ); ?>" class="logo sticky-logo" />
          <img src="<?php echo esc_url( $mobile_logo ); ?>" alt="<?php bloginfo( 'name' ); ?>" class="logo mobile-logo" />
        <?php else : ?>
          <div class="site-title"><?php bloginfo( 'name' ); ?></div>
        <?php endif; ?>
      </a>
      <button class="navbar-toggler" data-bs-target="#navbar-items" data-bs-toggle="collapse" aria-expanded="false">
        <span class="navbar-toggler-icon">
          <span class="line"></span>
          <span class="line"></span>
          <span class="line"></span>
        </span>
      </button>
      <div id="navbar-items" class="collapse navbar-collapse">
        <div class="navbar-collapse-form search-bar d-only-mobile d-none">
          <?php get_search_form(); ?>
        </div>
        <?php
        $nav_menu_location = '';
        if ( isset( get_nav_menu_locations()['menu-1'] ) ) {
          $nav_menu_location = get_nav_menu_locations()['menu-1'];
        }
       
        if ( wp_get_nav_menu_items( $nav_menu_location ) ) {
          wp_nav_menu(
            array(
              'theme_location' => 'menu-1',
              'container'      => false,
              'menu_class'     => '',
              'link_before'    => '<span class="text">',
              'link_after'     => '</span>',
              'items_wrap'     => '<ul id="%1$s" class="navbar-nav ms-auto%2$s">%3$s</ul>',
              'walker'         => new WP_Walker_Nav_Menu(),
              'fallback_cb'    => '__return_false',
            )
          );

        } else {
          echo '<div class="navbar-empty ms-auto"></div>';
        }
        ?>
        <ul class="navbar-nav navbar-icons d-only-desktop">
          <li class="search-bar simple-search-bar nav-item dropdown d-only-desktop">
            <a href="#!" class="nav-link dropdown-toggle" data-bs-toggle="dropdown">
              <i class="fa-solid fa-magnifying-glass icon"></i>
            </a>
            <div class="search-bar-dropdown dropdown-menu megamenu animate fade-down" role="menu">
              <div class="megamenu-item">                  
                <?php 
                printf(
                  /* translators: 1: page title */
                  '<h5 class="title search-form-title">%s</h5>',
                  esc_html__( 'What are you looking for?', 'gomax' )
                ); 
                get_search_form();
                ?>
              </div>
            </div>
          </li>
        </ul>
      </div>
    </div>
  </nav>
</header>