<?php
/**
 * This is the post block template displayed in loops.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

/**
 * Check post type.
 * 
 * @package Gomax
 * @since 1.0.0
 */
if ( is_singular( 'portfolio' ) ) {
  $categories = get_the_terms( get_the_ID(), 'portfolio-category' );

} else {
  $categories = get_the_category();
}

$post_class_attr = 'post-item tms-image-zoom';

if ( is_sticky() ) {
  $post_class_attr .= ' is-sticky';
}

/**
 * Set the image resolution.
 * 
 * @package Gomax
 * @since 1.0.0
 */
$columns = get_theme_mod( 'blog_columns', '1' );

switch ( $columns ) {
  case '1':
    $image_resolution = 'full';
    break;
  case '2':
    $image_resolution = 'gomax_grid_2_cols';
    break;
  case '3':
    $image_resolution = 'gomax_grid_3_cols';
    break;
  case '4':
    $image_resolution = 'gomax_grid_4_cols';
    break;
  case '5':
    $image_resolution = 'gomax_grid_4_cols';
    break;
  case '6':
    $image_resolution = 'gomax_grid_4_cols';
    break;
}

// Set full image resolution for search page.
if ( is_search() ) {
  $image_resolution = 'full';
}
?>
<div id="post-<?php the_ID(); ?>" class="<?php echo esc_attr( $post_class_attr ); ?>">
  <?php
  // Featured Post
  if ( is_sticky() ) : ?>
    <i class="fa-regular fa-bookmark icon"></i>
  <?php endif;

	// Thumbnail
  if ( has_post_thumbnail() ) :
    $permalink = get_permalink();
    ?>
    <div class="post-thumbnail">
      <?php
      // Post Categories
      if ( ! get_theme_mod( 'disable_categories' ) && ! empty( $categories ) ) {
        ?>
        <div class="post-categories">
          <div class="post-categories-wrapper">
            <?php foreach ( $categories as $category ) { ?>
              <a href="<?php echo get_category_link( $category->term_id ); ?>" class="link">                      
                <label class="category">
                  <?php echo esc_html( $category->name ); ?>
                </label>
              </a>
            <?php } ?>
          </div>
        </div>
      <?php
      }
      ?>      
      <div class="image-wrapper">
        <a href="<?php echo esc_url( $permalink ); ?>">
          <?php the_post_thumbnail( $image_resolution, array('class' => 'image') ); ?>
        </a>
      </div>
    </div>
    <?php 
  endif;
  ?>
  <div class="post-content">
    <?php  
    // Post Title
    if ( get_the_title() ) :
      printf(
        '<h3 class="title entry-title line-clamp-2">%s</h3>',
        sprintf(
          '<a href="%s">%s</a>',
          get_permalink(),
          get_the_title()
        )
      );
    else :
      printf(
        '<h3 class="title entry-title line-clamp-2">%s</h3>',
        sprintf(
          '<a href="%s">%s</a>',
          get_permalink(),
          esc_html__( 'View Post', 'gomax' )
        )
      );
    endif;
    
    // Post Excerpt
    if ( get_the_excerpt() ) {
      printf(
        '<div class="post-excerpt line-clamp-3">%s</div>',
        get_the_excerpt()
      );
    }

    // Post Metadata
    if ( ! get_theme_mod( 'disable_post_metadata' ) ) :       

      // Post Author
      $author_type = get_the_author_meta( 'display_name' );
      $post_author = sprintf(
        '<label class="label-horizontal">%s%s</label>',
        '<span class="label-line"></span>',
        sprintf(
          '<span class="author-name">%s</span>',
          sprintf(
            '<a href="%s" target="_blank">%s</a>',
            get_the_author_meta( 'user_url' ),
            $author_type
          )
        )
      );

      // Post Date
      $date_type = get_the_date();  
      $post_date = sprintf(
        '<label class="post-date">%s</label>',
        $date_type
      );

      // Post Metadata
      printf(
        '<div class="post-metadata">%s%s</div>',
        $post_author,
        $post_date
      );

    endif;
    ?>
  </div>
</div>