<?php
/**
 * This template is displayed when a page is search.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

// If there are search results
if ( have_posts() ) {
	$section_class_attr = 'intro-section pt-5';

} else {
	$section_class_attr = 'intro-section pt-5 pb-5';
}
?>
<main id="main" class="main-section">
	<section class="<?php echo esc_attr( $section_class_attr ); ?>">
		<div class="container">
			<?php 
			// If there are search results
			if ( have_posts() ) :
				?>
				<div class="container-inner">
					<div class="post-intro-title">
						<?php
						// Avoid empty text in search
						if ( get_search_query() === '' ) {
							printf(
								/* translators: %1$s - text */
								'<h1 class="title entry-title">%1$s</h1>',
								esc_html__( 'Showing all results', 'gomax' ),
							);
							
						} else {
							printf(
								/* translators: %1$s - text, %2$s - search query */
								'<h1 class="title entry-title">%1$s: <em>%2$s</em></h1>',
								esc_html__( 'Search Results For', 'gomax' ),
								esc_html__( get_search_query() )
							);
						} 
						?>
					</div>
				</div>
			<?php else : ?>
				<div class="page-search">
					<div class="text-center">
						<?php
						printf(
							/* translators: 1: page title */
							'<h1 class="title entry-title">%s</h1>',
							esc_html__( 'No Results Found', 'gomax' )
						);
						printf(
							/* translators: 1: page description */
							'<p class="description max-w-65 mx-auto">%s</p>',
							esc_html__( 'Unfortunately, there are no matching results for your query. It is possible that what you are looking for is hidden in a different corner of our website. Feel free to refine your search terms.', 'gomax' )
						); 
						?>
					</div>	
					<div class="search-form">
						<?php get_search_form(); ?>
					</div>
				</div>
			<?php endif; ?>
		</div>
	</section>
	<?php
	// List search results
	if ( have_posts() ) :
		?>
		<section class="search-section pt-5 pb-5">
			<div class="container">
				<div class="archive-page container-inner">
					<?php gomax_get_breadcrumb(); ?>
					<div class="post-grid">
						<?php
						while ( have_posts() ) {
							the_post();
							get_template_part( 'template-parts/post' );
						}
						wp_reset_postdata();

						$pagination_args = array(
							'current'   => max( 1, get_query_var( 'paged' ) ),
							'end_size'  => 1,
							'mid_size'  => 2,
							'prev_text' => '<i class="fa-solid fa-arrow-left-long icon"></i>',
							'next_text' => '<i class="fa-solid fa-arrow-right-long icon"></i>',
							'type'      => 'list'
						);

						if ( get_the_posts_pagination( $pagination_args ) ) {
							the_posts_pagination( $pagination_args );
						}
						?>
					</div>
				</div>
			</div>
		</section>
	<?php endif; ?>
</main>