<?php
/**
 * This template is displayed when a page is single.
 * 
 * @package Gomax
 * @since 1.0.0
 */

defined( 'ABSPATH' ) || exit; // Exit if accessed directly.

while ( have_posts() ) : 
	the_post();

	/**
	 * Check post type.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	if ( is_singular( 'post' ) ) {
		$is_post      = true;
		$is_portfolio = false;
		$sidebar      = 'post-sidebar';
		$categories   = get_the_category();

	} elseif ( is_singular( 'portfolio' ) ) {
		$is_post      = false;
		$is_portfolio = true;
		$sidebar      = 'portfolio-sidebar';
		$categories   = get_the_terms( get_the_ID(), 'portfolio-category' );

	} elseif ( is_singular( 'page' ) ) {
		$is_post      = false;
		$is_portfolio = false;
		$sidebar      = 'page-sidebar';
		$categories   = get_the_category();

	} else {		
		$is_post      = '';
		$is_portfolio = '';
		$sidebar      = '';
		$categories   = get_the_category();
	}

	/**
	 * Get the page title.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	$page_title = get_the_title();

	/**
	 * Set the container classes.
	 * 
	 * @package Gomax
	 * @since 1.0.0
	 */
	$container_class_attr = 'container';
	if ( has_excerpt() && has_post_thumbnail() || ! has_post_thumbnail() && gomax_has_sidebar( $sidebar ) ) {
		$container_class_attr .= ' full-container';
	}

	$content_container_class_attr = 'container';
	if ( gomax_has_sidebar( $sidebar ) ) {
		$content_container_class_attr .= ' full-container';
	}

	$row_class_attr = 'row g-0';
	$col_class_attr = 'col-12';
	if ( gomax_has_sidebar( $sidebar ) ) {
		$row_class_attr .= 'row g-5';
		$col_class_attr .= ' col-md-8';
	}
	?>
	<main id="main" class="main-section">
		<section class="intro-section pt-5">
			<div class="<?php echo esc_attr( $container_class_attr ); ?>">
				<div class="container-inner">
					<?php
					$intro_class_attr = 'post-intro-title';
					// Add the class if the post is sticky.
					if ( is_sticky() ) {
						$intro_class_attr .= ' is-sticky';
					}
					// Add a class if and thumbnail excerpt exists.
					$excerpt_col_class_attr = 'col-12';
					if ( has_excerpt() && has_post_thumbnail() ) {
						$excerpt_col_class_attr .= ' col-md-7';
					}
					// Add a class if the excerpt doesn't exist but has a thumbnail.
					if ( ! has_excerpt() && has_post_thumbnail() ) {
						$intro_class_attr .= ' align-to-center';
					}
					// Add a class if the excerpt and thumbnail doesn't exist.
					if ( ! has_excerpt() && ! has_post_thumbnail() ) {
						$intro_class_attr .= ' align-to-center';
						$intro_class_attr .= ' text-center';
					}
					?>
					<div class="<?php echo esc_attr( $intro_class_attr ); ?>">
						<?php						
						// Featured Post
						if ( $is_post || $is_portfolio ) :
							if ( is_sticky() && ! has_post_thumbnail() ) : ?>
								<i class="fa-regular fa-bookmark icon"></i>
							<?php
							endif;
						endif;
						// Post Categories
						if ( $is_post || $is_portfolio ) {
							if ( ! get_theme_mod( 'disable_categories' ) && ! empty( $categories ) ) {
								?>
								<div id="post-categories" class="post-categories">
									<div class="badge-wrapper">
										<?php foreach ( $categories as $category ) { ?>
											<a href="<?php echo get_category_link( $category->term_id ); ?>" class="badge">                      
												<span class="badge-text"><?php echo esc_html( $category->name ); ?></span>
											</a>
										<?php } ?>
									</div>
								</div>
							<?php
							}
						}
						?>
						<div class="row">
							<div class="<?php echo esc_attr( $excerpt_col_class_attr ); ?>">
								<?php
								// Post Title
								if ( $page_title ) :
									printf(
										'<h1 class="title entry-title">%s</h1>',
										$page_title
									);
								endif;						
								// Post Excerpt
								if ( has_excerpt() && ! has_post_thumbnail() ) {
									printf(
										'<p class="description post-excerpt">%s</p>',
										get_the_excerpt()
									);
								}
								// Post Metadata
								if ( ! get_theme_mod( 'disable_post_metadata' ) && $is_post || $is_portfolio ) {
									printf(
										'<div class="post-metadata">%s%s</div>',
										sprintf(
											'<label class="label-horizontal">%s%s</label>',
											'<span class="label-line"></span>',
											sprintf(
												'<span class="author-name">%s</span>',
												sprintf(
													'<a href="%s" target="_blank">%s</a>',
													get_the_author_meta( 'user_url' ),
													get_the_author_meta( 'display_name' )
												)
											)
										),
										sprintf(
											'<label class="post-date">%s</label>',
											get_the_date()
										)
									);
								}
								?>
							</div>
								<?php
								// Post Excerpt
								if ( has_excerpt() && has_post_thumbnail() ) :
									?>
									<div class="col-12 col-md-5">
										<?php
										printf(
											'<p class="description post-excerpt">%s</p>',
											get_the_excerpt()
										);
										?>
									</div>
								<?php endif; ?>
						</div>
					</div>					
				</div>
				<?php
				// Post Thumbnail
				if ( has_post_thumbnail() ) : 
					?>
					<div class="post-thumbnail">
						<div class="image-wrapper">
							<?php
							// Featured Post
							if ( is_sticky() ) : ?>
								<i class="fa-regular fa-bookmark icon"></i>
							<?php endif;
							// Post Thumbnail
							the_post_thumbnail( 'full', array( 'class' => 'image w-auto mx-auto fit-cover rounded' ) ); ?>
						</div>
					</div>
					<?php 
				endif;
				?>
			</div>
		</section>
		<!-- Content -->
		<section id="post-<?php the_ID(); ?>" <?php post_class( 'content-section pt-5 pb-5' ); ?>>
			<div class="<?php echo esc_attr( $content_container_class_attr ) ?>">
				<div class="container-inner">
					<div class="<?php echo esc_attr( $row_class_attr ) ?>">
						<div class="<?php echo esc_attr( $col_class_attr ) ?>">
							<div class="content-page">
								<?php gomax_get_breadcrumb(); ?>						
								<article class="is-layout-flow">
									<?php the_content(); ?>
								</article>
								<?php
								wp_link_pages( array(
									'before' => '<nav class="pagination mt-3 mb-3"><div class="nav-links"><div class="page-numbers">',
									'after'  => '</div></div></nav>',
								) );

								edit_post_link(
									'<span class="button-text">' . __( 'Edit', 'gomax' ). '</span>' . '<i class="fa-solid fa-pen-to-square button-icon"></i>', 
									'<div class="post-edit-link-wrapper">', '</div>', '', 'post-edit-link button light'
								);

								if ( $is_post || $is_portfolio ) {
									gomax_get_post_navigation();
									gomax_get_post_reference();
									gomax_get_post_taxonomy();
								};
																
								comments_template();
								?>
							</div>
						</div>
						<?php gomax_get_sidebar( $sidebar ); ?>
					</div>
				</div>
			</div>
		</section>	
	</main>
	<?php
endwhile;